@@ -396,8 +396,11 @@ static gboolean bar_pane_gps_marker_keypress_cb(GtkWidget *widget, ClutterButton
 			g_string_free(text, TRUE);
 
 			parent_marker = clutter_actor_get_parent(label_marker);
-			direction = clutter_actor_get_child_at_index(parent_marker, 0);
-			clutter_actor_set_opacity(direction, 255);
+			if (clutter_actor_get_n_children(parent_marker ) > 1 )
+				{
+				direction = clutter_actor_get_child_at_index(parent_marker, 0);
+				clutter_actor_set_opacity(direction, 255);
+				}
 			}
 		/* otherwise, revert to the hidden text marker
 		 */
@@ -409,8 +412,11 @@ static gboolean bar_pane_gps_marker_keypress_cb(GtkWidget *widget, ClutterButton
 			champlain_marker_set_selection_text_color(&marker_colour);
 
 			parent_marker = clutter_actor_get_parent(label_marker);
-			direction = clutter_actor_get_child_at_index(parent_marker, 0);
-			clutter_actor_set_opacity(direction, 0);
+			if (clutter_actor_get_n_children(parent_marker ) > 1 )
+				{
+				direction = clutter_actor_get_child_at_index(parent_marker, 0);
+				clutter_actor_set_opacity(direction, 0);
+				}
 			}
 
 		g_free(current_text);
@@ -668,6 +674,7 @@ static void bar_pane_gps_write_config(GtkWidget *pane, GString *outstr, gint ind
 	GString *buffer = g_string_new(str);
 	gdouble position;
 	gint int_position;
+	gint w, h;
 
 	pgd = g_object_get_data(G_OBJECT(pane), "pane_data");
 	if (!pgd) return;
@@ -677,6 +684,10 @@ static void bar_pane_gps_write_config(GtkWidget *pane, GString *outstr, gint ind
 	write_char_option(outstr, indent, "id", pgd->pane.id);
 	write_char_option(outstr, indent, "title", gtk_label_get_text(GTK_LABEL(pgd->pane.title)));
 	WRITE_BOOL(pgd->pane, expanded);
+
+	gtk_widget_get_size_request(GTK_WIDGET(pane), &w, &h);
+	pgd->height = h;
+
 	WRITE_INT(*pgd, height);
 	indent++;
 
@@ -945,7 +956,7 @@ GtkWidget *bar_pane_gps_new(const gchar *id, const gchar *title, const gchar *ma
 
 	status = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
 	slider = gtk_scale_button_new(GTK_ICON_SIZE_SMALL_TOOLBAR, 1, 17, 1, slider_icons);
-	gtk_widget_set_tooltip_text(slider, "Zoom");
+	gtk_widget_set_tooltip_text(slider, _("Zoom"));
 	gtk_scale_button_set_value(GTK_SCALE_BUTTON(slider), (gdouble)zoom);
 
 	progress = gtk_progress_bar_new();
@@ -954,7 +965,9 @@ GtkWidget *bar_pane_gps_new(const gchar *id, const gchar *title, const gchar *ma
 	gtk_progress_bar_set_show_text(GTK_PROGRESS_BAR(progress), TRUE);
 #endif
 	state = gtk_label_new("");
-	gtk_label_set_justify(GTK_LABEL(state), GTK_JUSTIFY_CENTER);
+	gtk_label_set_justify(GTK_LABEL(state), GTK_JUSTIFY_LEFT);
+	gtk_label_set_ellipsize(GTK_LABEL(state), PANGO_ELLIPSIZE_START);
+	gtk_widget_set_tooltip_text(state, _("Zoom level"));
 
 	gtk_box_pack_start(GTK_BOX(status), GTK_WIDGET(slider), FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(status), GTK_WIDGET(state), FALSE, FALSE, 5);
@@ -1016,7 +1029,7 @@ GtkWidget *bar_pane_gps_new_from_config(const gchar **attribute_names, const gch
 	gdouble latitude;
 	gdouble longitude;
 	/* Latitude and longitude are stored in the config file as an integer of
-	 * (actual value * 1,000,000). There is no READ_DOUBLE utilty function.
+	 * (actual value * 1,000,000). There is no READ_DOUBLE utility function.
 	 */
 	gint int_latitude = 54000000;
 	gint int_longitude = -4000000;
