@@ -303,11 +303,13 @@ static void bar_pane_keywords_write_config(GtkWidget *pane, GString *outstr, gin
 {
 	PaneKeywordsData *pkd;
 	GList *path_expanded = NULL;
+	gint w, h;
 
 	pkd = g_object_get_data(G_OBJECT(pane), "pane_data");
 	if (!pkd) return;
 
-	pkd->height = options->info_keywords.height;
+	gtk_widget_get_size_request(GTK_WIDGET(pane), &w, &h);
+	pkd->height = h;
 
 	WRITE_NL(); WRITE_STRING("<pane_keywords ");
 	write_char_option(outstr, indent, "id", pkd->pane.id);
@@ -1241,7 +1243,7 @@ static void bar_pane_keywords_hide_unchecked_toggle_cb(GtkWidget *menu_widget, g
 }
 
 /**
- * \brief Callback for adding selected keyword to all selected images.
+ * @brief Callback for adding selected keyword to all selected images.
  */
 static void bar_pane_keywords_add_to_selected_cb(GtkWidget *menu_widget, gpointer data)
 {
@@ -1255,7 +1257,7 @@ static void bar_pane_keywords_add_to_selected_cb(GtkWidget *menu_widget, gpointe
 
 	GtkTextBuffer *keyword_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(pkd->keyword_view));
 
-	/* Aquire selected keyword */
+	/* Acquire selected keyword */
 	if (pkd->click_tpath)
 		{
 		gboolean is_keyword = TRUE;
