@@ -104,15 +104,16 @@ void editor_description_free(EditorDescription *editor)
 
 static GList *editor_mime_types_to_extensions(gchar **mime_types)
 {
-	/* FIXME: this should be rewritten to use the shared mime database, as soon as we switch to gio */
+	/** @FIXME this should be rewritten to use the shared mime database, as soon as we switch to gio */
 
 	static const gchar *conv_table[][2] = {
-		{"application/x-ufraw",	".ufraw"},
 		{"image/*",		"*"},
 		{"image/bmp",		".bmp"},
 		{"image/gif",		".gif"},
+		{"image/heic",		".heic"},
 		{"image/jpeg",		".jpeg;.jpg;.mpo"},
 		{"image/jpg",		".jpg;.jpeg"},
+		{"image/webp",		".webp"},
 		{"image/pcx",		".pcx"},
 		{"image/png",		".png"},
 		{"image/svg",		".svg"},
@@ -457,7 +458,7 @@ GList *editor_get_desktop_files(void)
 	else
 		xdg_data_dirs = g_strdup("/usr/share");
 
-	all_dirs = g_strconcat(get_rc_dir(), ":", GQ_APP_DIR, ":", xdg_data_home_get(), ":", xdg_data_dirs, NULL);
+	all_dirs = g_strconcat(get_rc_dir(), ":", gq_app_dir, ":", xdg_data_home_get(), ":", xdg_data_dirs, NULL);
 
 	g_free(xdg_data_dirs);
 
@@ -1083,7 +1084,7 @@ static EditorFlags editor_command_one(const EditorDescription *editor, GList *li
 		args[n++] = command;
 		args[n] = NULL;
 
-		if ((ed->flags & EDITOR_DEST) && fd && fd->change && fd->change->dest) /* FIXME: error handling */
+		if ((ed->flags & EDITOR_DEST) && fd && fd->change && fd->change->dest) /** @FIXME error handling */
 			{
 			g_setenv("GEEQIE_DESTINATION", fd->change->dest, TRUE);
 			}
