@@ -450,6 +450,10 @@ void exif_init(void)
 #ifdef EXV_ENABLE_NLS
 	bind_textdomain_codeset (EXV_PACKAGE, "UTF-8");
 #endif
+
+#ifdef EXV_ENABLE_BMFF
+	Exiv2::enableBMFF(TRUE);
+#endif
 }
 
 
@@ -815,7 +819,7 @@ gchar *exif_item_get_string(ExifItem *item, int idx)
 #if EXIV2_TEST_VERSION(0,16,0)
 		std::string str = em->toString(idx);
 #else
-		std::string str = em->toString(); // FIXME
+		std::string str = em->toString(); /**< @FIXME ?? */
 #endif
 		if (idx == 0 && str == "") str = em->toString();
 		if (str.length() > 5 && str.substr(0, 5) == "lang=")
@@ -977,7 +981,7 @@ gint exif_update_metadata(ExifData *exif, const gchar *key, const GList *values)
 	    TRUE || /* no conversion support */
 #endif
 	    !values || /* deleting item */
-	    !ret  /* writing to the explicitely given xmp tag failed */
+	    !ret  /* writing to the explicitly given xmp tag failed */
 	    )
 		{
 		/* deleted xmp metadatum can't be converted, we have to delete also the corresponding legacy tag */
