@@ -113,16 +113,16 @@ gchar *text_from_size_abrev(gint64 size)
 		}
 	if (size < (gint64)1048576)
 		{
-		return g_strdup_printf(_("%.1f K"), (gdouble)size / 1024.0);
+		return g_strdup_printf(_("%.1f KiB"), (gdouble)size / 1024.0);
 		}
 	if (size < (gint64)1073741824)
 		{
-		return g_strdup_printf(_("%.1f MB"), (gdouble)size / 1048576.0);
+		return g_strdup_printf(_("%.1f MiB"), (gdouble)size / 1048576.0);
 		}
 
 	/* to avoid overflowing the gdouble, do division in two steps */
 	size /= 1048576;
-	return g_strdup_printf(_("%.1f GB"), (gdouble)size / 1024.0);
+	return g_strdup_printf(_("%.1f GiB"), (gdouble)size / 1024.0);
 }
 
 /* note: returned string is valid until next call to text_from_time() */
@@ -716,6 +716,7 @@ static void file_data_free(FileData *fd)
 	g_free(fd->owner);
 	g_free(fd->group);
 	g_free(fd->sym_link);
+	g_free(fd->format_name);
 	g_assert(fd->sidecar_files == NULL); /* sidecar files must be freed before calling this */
 
 	file_data_change_info_free(NULL, fd);
@@ -723,7 +724,7 @@ static void file_data_free(FileData *fd)
 }
 
 /**
- * \brief Checks if the FileData is referenced
+ * @brief Checks if the FileData is referenced
  *
  * Checks the refcount and whether the FileData is locked.
  */
@@ -733,7 +734,7 @@ static gboolean file_data_check_has_ref(FileData *fd)
 }
 
 /**
- * \brief Consider freeing a FileData.
+ * @brief Consider freeing a FileData.
  *
  * This function will free a FileData and its children provided that neither its parent nor it has
  * a positive refcount, and provided that neither is locked.
@@ -801,7 +802,7 @@ void file_data_unref(FileData *fd)
 }
 
 /**
- * \brief Lock the FileData in memory.
+ * @brief Lock the FileData in memory.
  *
  * This allows the caller to prevent a FileData from being freed, even after its refcount is zero.
  * This is intended to be used in cases where a FileData _should_ stay in memory as an optimization,
@@ -823,7 +824,7 @@ void file_data_lock(FileData *fd)
 }
 
 /**
- * \brief Reset the maintain-FileData-in-memory lock
+ * @brief Reset the maintain-FileData-in-memory lock
  *
  * This again allows the FileData to be freed when its refcount drops to zero.  Automatically frees
  * the FileData if its refcount is already zero (which will happen if the lock is the only thing
@@ -842,9 +843,9 @@ void file_data_unlock(FileData *fd)
 }
 
 /**
- * \brief Lock all of the FileDatas in the provided list
+ * @brief Lock all of the FileDatas in the provided list
  *
- * \see file_data_lock(FileData)
+ * @see file_data_lock(#FileData)
  */
 void file_data_lock_list(GList *list)
 {
@@ -860,9 +861,9 @@ void file_data_lock_list(GList *list)
 }
 
 /**
- * \brief Unlock all of the FileDatas in the provided list
+ * @brief Unlock all of the FileDatas in the provided list
  *
- * \see file_data_unlock(FileData)
+ * @see #file_data_unlock(#FileData)
  */
 void file_data_unlock_list(GList *list)
 {
@@ -2027,7 +2028,7 @@ gchar *file_data_sc_list_to_string(FileData *fd)
    COPY
    MOVE   - path is changed, name may be changed too
    RENAME - path remains unchanged, name is changed
-            extension should remain (FIXME should we allow editing extension? it will make problems wth grouping)
+            extension should remain (FIXME should we allow editing extension? it will make problems with grouping)
 	    sidecar names are changed too, extensions are not changed
    DELETE
    UPDATE - file size, date or grouping has been changed
@@ -2667,7 +2668,7 @@ gint file_data_verify_ci(FileData *fd, GList *list)
 			}
 		else
 			{
-			if (fd->change->type != FILEDATA_CHANGE_UNSPECIFIED) /* FIXME this is now needed for running editors */
+			if (fd->change->type != FILEDATA_CHANGE_UNSPECIFIED) /** @FIXME this is now needed for running editors */
 		   		{
 				ret |= CHANGE_WARN_SAME;
 				DEBUG_1("Change checked: source and destination are the same: %s -> %s", fd->path, fd->change->dest);
@@ -3003,7 +3004,7 @@ gboolean file_data_apply_ci(FileData *fd)
 {
 	FileDataChangeType type = fd->change->type;
 
-	/* FIXME delete ?*/
+	/** @FIXME delete ?*/
 	if (type == FILEDATA_CHANGE_MOVE || type == FILEDATA_CHANGE_RENAME)
 		{
 		DEBUG_1("planned change: applying %s -> %s", fd->change->dest, fd->path);
@@ -3014,7 +3015,8 @@ gboolean file_data_apply_ci(FileData *fd)
 			/* this change overwrites another file which is already known to other modules
 			   renaming fd would create duplicate FileData structure
 			   the best thing we can do is nothing
-			   FIXME: maybe we could copy stuff like marks
+			*/
+			/**  @FIXME maybe we could copy stuff like marks
 			*/
 			DEBUG_1("can't rename fd, target exists %s -> %s", fd->change->dest, fd->path);
 			}
@@ -3090,7 +3092,7 @@ GList *file_data_process_groups_in_selection(GList *list, gboolean ungroup, GLis
 		}
 
 	/* remove sidecars from the list,
-	   they can be still acessed via main_fd->sidecar_files */
+	   they can be still accessed via main_fd->sidecar_files */
 	work = list;
 	while (work)
 		{
@@ -3118,8 +3120,8 @@ GList *file_data_process_groups_in_selection(GList *list, gboolean ungroup, GLis
  * notify other modules about the change described by FileDataChangeInfo
  */
 
-/* might use file_maint_ functions for now, later it should be changed to a system of callbacks
-   FIXME do we need the ignore_list? It looks like a workaround for ineffective
+/* might use file_maint_ functions for now, later it should be changed to a system of callbacks */
+/** @FIXME do we need the ignore_list? It looks like a workaround for ineffective
    implementation in view_file_list.c */
 
 
