@@ -27,14 +27,19 @@
 #include "image_load_tiff.h"
 #include "image_load_dds.h"
 #include "image_load_djvu.h"
+#include "image_load_external.h"
 #include "image_load_pdf.h"
 #include "image_load_psd.h"
 #include "image_load_heif.h"
 #include "image_load_ffmpegthumbnailer.h"
 #include "image_load_collection.h"
 #include "image_load_webp.h"
+#include "image_load_zxscr.h"
 #include "image_load_j2k.h"
+#include "image_load_jpegxl.h"
+#include "image_load_libraw.h"
 #include "image_load_svgz.h"
+#include "misc.h"
 
 #include "exif.h"
 #include "filedata.h"
@@ -47,7 +52,68 @@
 #define IMAGE_LOADER_READ_BUFFER_SIZE_DEFAULT 	4096
 #define IMAGE_LOADER_IDLE_READ_LOOP_COUNT_DEFAULT 	1
 
-
+/**
+ * @page diagrams Diagrams
+ * @section image_load_overview Image Load Overview
+ * @startuml
+ * object image_change
+ * object image_change_complete
+ * object image_load_begin
+ * object image_loader_start
+ * object image_loader_start_thread
+ * object image_loader_start_idle
+ * object image_loader_setup_source
+ * object image_loader_thread_run
+ * object image_loader_begin
+ * object image_loader_setuploader
+ * circle "il->memory_mapped"
+ * object exif_get_preview_
+ * object exif_get_preview
+ * object libraw_get_preview
+ * 
+ * image_change : image.c
+ * image_change_complete : image.c
+ * image_load_begin : image.c
+ * image_loader_start : image_load.c
+ * image_loader_start_thread : image_load.c
+ * image_loader_start_idle : image_load.c
+ * image_loader_thread_run : image_load.c
+ * image_loader_begin : image_load.c
+ * image_loader_setuploader : image_load.c
+ * image_loader_setuploader : -
+ * image_loader_setuploader : Select backend using magic
+ * image_loader_setup_source : image_load.c
+ * exif_get_preview : exiv2.cc
+ * exif_get_preview : EXIV2_TEST_VERSION(0,17,90)
+ * exif_get_preview_ : exif.c
+ * exif_get_preview_ : -
+ * exif_get_preview_ : If exiv2 not installed
+ * libraw_get_preview : image_load_libraw.c
+ * 
+ * image_change --> image_change_complete
+ * image_change_complete --> image_load_begin
+ * image_load_begin --> image_loader_start
+ * image_loader_start --> image_loader_start_thread
+ * image_loader_start --> image_loader_start_idle : Obsolete - no threads version
+ * image_loader_start_thread --> image_loader_thread_run
+ * image_loader_start_thread --> image_loader_setup_source
+ * image_loader_setup_source --> exif_get_preview_
+ * image_loader_setup_source --> exif_get_preview
+ * image_loader_setup_source --> libraw_get_preview : Try libraw if exiv2 fails
+ * exif_get_preview_ ..> "il->memory_mapped"
+ * exif_get_preview ..> "il->memory_mapped"
+ * libraw_get_preview ..> "il->memory_mapped"
+ * image_loader_thread_run --> image_loader_begin
+ * image_loader_begin --> image_loader_setuploader
+ * "il->memory_mapped" ..> image_loader_setuploader
+ * note left of "il->memory_mapped" : Points to first byte of embedded jpeg (#FFD8)\n if preview found, otherwise to first byte of file
+ * @enduml
+ */
+ /**
+  * @file
+  * @ref image_load_overview "Image Load Overview"
+  */
+  
 /**************************************************************************************/
 /* image loader class */
 
@@ -109,6 +175,7 @@ static void image_loader_init(GTypeInstance *instance, gpointer g_class)
 	il->idle_read_loop_count = IMAGE_LOADER_IDLE_READ_LOOP_COUNT_DEFAULT;
 	il->read_buffer_size = IMAGE_LOADER_READ_BUFFER_SIZE_DEFAULT;
 	il->mapped_file = NULL;
+	il->preview = IMAGE_LOADER_PREVIEW_NONE;
 
 	il->requested_width = 0;
 	il->requested_height = 0;
@@ -340,7 +407,7 @@ static gboolean image_loader_emit_size_cb(gpointer data)
 }
 
 
-/* DONE and ERROR are emited only once, thus they can have normal priority
+/* DONE and ERROR are emitted only once, thus they can have normal priority
    PERCENT and AREA_READY should be processed ASAP
 */
 
@@ -627,7 +694,31 @@ static void image_loader_setup_loader(ImageLoader *il)
 	gchar *format;
 #endif
 
+	gint external_preview = 1;
+
 	g_mutex_lock(il->data_mutex);
+
+	if (options->external_preview.enable)
+		{
+		gchar *cmd_line;
+		gchar *tilde_filename;
+
+		tilde_filename = expand_tilde(options->external_preview.select);
+
+		cmd_line = g_strdup_printf("\"%s\" \"%s\"" , tilde_filename, il->fd->path);
+
+		external_preview = runcmd(cmd_line);
+		g_free(cmd_line);
+		g_free(tilde_filename);
+		}
+
+	if (external_preview == 0)
+		{
+		DEBUG_1("Using custom external loader");
+		image_loader_backend_set_external(&il->backend);
+		}
+	else
+
 #ifdef HAVE_FFMPEGTHUMBNAILER
 	if (il->fd->format_class == FORMAT_CLASS_VIDEO)
 		{
@@ -649,7 +740,8 @@ static void image_loader_setup_loader(ImageLoader *il)
 	if (il->bytes_total >= 12 &&
 		((memcmp(il->mapped_file + 4, "ftypheic", 8) == 0) ||
 		(memcmp(il->mapped_file + 4, "ftypmsf1", 8) == 0) ||
-		(memcmp(il->mapped_file + 4, "ftypmif1", 8) == 0)))
+		(memcmp(il->mapped_file + 4, "ftypmif1", 8) == 0) ||
+		(memcmp(il->mapped_file + 4, "ftypavif", 8) == 0)))
 		{
 		DEBUG_1("Using custom heif loader");
 		image_loader_backend_set_heif(&il->backend);
@@ -682,6 +774,7 @@ static void image_loader_setup_loader(ImageLoader *il)
 		DEBUG_1("Using custom jpeg loader");
 		image_loader_backend_set_jpeg(&il->backend);
 		}
+#ifndef HAVE_RAW
 	else
 	if (il->bytes_total >= 11 &&
 		(memcmp(il->mapped_file + 4, "ftypcrx", 7) == 0) &&
@@ -690,6 +783,7 @@ static void image_loader_setup_loader(ImageLoader *il)
 		DEBUG_1("Using custom cr3 loader");
 		image_loader_backend_set_cr3(&il->backend);
 		}
+#endif
 	else
 #endif
 #ifdef HAVE_TIFF
@@ -726,6 +820,29 @@ static void image_loader_setup_loader(ImageLoader *il)
 		}
 	else
 #endif
+#ifdef HAVE_JPEGXL
+	if (il->bytes_total >= 12 &&
+		(memcmp(il->mapped_file, "\0\0\0\x0C\x4A\x58\x4C\x20\x0D\x0A\x87\x0A", 12) == 0))
+		{
+		DEBUG_1("Using custom jpeg xl loader");
+		image_loader_backend_set_jpegxl(&il->backend);
+		}
+	else
+	if (il->bytes_total >= 2 &&
+		(memcmp(il->mapped_file, "\xFF\x0A", 2) == 0))
+		{
+		DEBUG_1("Using custom jpeg xl loader");
+		image_loader_backend_set_jpegxl(&il->backend);
+		}
+	else
+#endif
+	if ((il->bytes_total == 6144 || il->bytes_total == 6912) &&
+		(file_extension_match(il->fd->path, ".scr")))
+		{
+		DEBUG_1("Using custom zxscr loader");
+		image_loader_backend_set_zxscr(&il->backend);
+		}
+	else
 	if (il->fd->format_class == FORMAT_CLASS_COLLECTION)
 		{
 		DEBUG_1("Using custom collection loader");
@@ -778,6 +895,8 @@ static void image_loader_setup_loader(ImageLoader *il)
 	g_free(format);
 #endif
 
+	il->fd->format_name = il->backend.get_format_name(il->loader);
+
 	g_mutex_unlock(il->data_mutex);
 }
 
@@ -954,13 +1073,53 @@ static gboolean image_loader_setup_source(ImageLoader *il)
 		ExifData *exif = exif_read_fd(il->fd);
 
 		if (options->thumbnails.use_exif)
+			{
 			il->mapped_file = exif_get_preview(exif, (guint *)&il->bytes_total, il->requested_width, il->requested_height);
+
+			if (il->mapped_file)
+				{
+				il->preview = IMAGE_LOADER_PREVIEW_EXIF;
+				}
+			}
 		else
+			{
 			il->mapped_file = exif_get_preview(exif, (guint *)&il->bytes_total, 0, 0); /* get the largest available preview image or NULL for normal images*/
 
+			if (il->mapped_file)
+				{
+				/* Both exiv2 and libraw sometimes return a pointer to a file
+				 * section that is not a jpeg */
+				if (!(il->mapped_file[0] == 0xFF && il->mapped_file[1] == 0xD8))
+					{
+					il->mapped_file = NULL;
+					}
+				else
+					{
+					il->preview = IMAGE_LOADER_PREVIEW_EXIF;
+					}
+				}
+			}
+
+		/* If exiv2 does not find a thumbnail, try libraw (which may be slower) */
+		if (!il->mapped_file)
+			{
+			il->mapped_file = libraw_get_preview(il, (guint *)&il->bytes_total);
+
+			if (il->mapped_file)
+				{
+				if (!(il->mapped_file[0] == 0xFF && il->mapped_file[1] == 0xD8))
+					{
+					il->mapped_file = NULL;
+					}
+				else
+					{
+					il->preview = IMAGE_LOADER_PREVIEW_LIBRAW;
+					}
+				}
+			}
+
 		if (il->mapped_file)
 			{
-			il->preview = TRUE;
 			DEBUG_1("Usable reduced size (preview) image loaded from file %s", il->fd->path);
 			}
 		exif_free_fd(il->fd, exif);
@@ -994,7 +1153,7 @@ static gboolean image_loader_setup_source(ImageLoader *il)
 			il->mapped_file = 0;
 			return FALSE;
 			}
-		il->preview = FALSE;
+		il->preview = IMAGE_LOADER_PREVIEW_NONE;
 		}
 
 	return TRUE;
@@ -1006,10 +1165,14 @@ static void image_loader_stop_source(ImageLoader *il)
 
 	if (il->mapped_file)
 		{
-		if (il->preview)
+		if (il->preview == IMAGE_LOADER_PREVIEW_EXIF)
 			{
 			exif_free_preview(il->mapped_file);
 			}
+		else if (il->preview == IMAGE_LOADER_PREVIEW_LIBRAW)
+			{
+			libraw_free_preview(il->mapped_file);
+			}
 		else
 			{
 			munmap(il->mapped_file, il->bytes_total);
@@ -1158,7 +1321,7 @@ static void image_loader_thread_run(gpointer data, gpointer user_data)
 
 	if (il->idle_priority > G_PRIORITY_DEFAULT_IDLE)
 		{
-		/* low prio, wait untill high prio tasks finishes */
+		/* low prio, wait until high prio tasks finishes */
 		image_loader_thread_wait_high();
 		}
 	else
@@ -1185,7 +1348,7 @@ static void image_loader_thread_run(gpointer data, gpointer user_data)
 		{
 		if (il->idle_priority > G_PRIORITY_DEFAULT_IDLE)
 			{
-			/* low prio, wait untill high prio tasks finishes */
+			/* low prio, wait until high prio tasks finishes */
 			image_loader_thread_wait_high();
 			}
 		cont = image_loader_continue(il);
@@ -1362,7 +1525,9 @@ const gchar *image_loader_get_error(ImageLoader *il)
 }
 
 
-/* FIXME - this can be rather slow and blocks until the size is known */
+/**
+ *  @FIXME this can be rather slow and blocks until the size is known
+ */
 gboolean image_load_dimensions(FileData *fd, gint *width, gint *height)
 {
 	ImageLoader *il;
