@@ -206,7 +206,7 @@ static void layout_box_folders_changed_cb(GtkWidget *widget, gpointer data)
 	LayoutWindow *lw;
 	GList *work;
 
-/* FIXME: this is probably not the correct way to implement this */
+/** @FIXME this is probably not the correct way to implement this */
 	work = layout_window_list;
 	while (work)
 		{
@@ -503,15 +503,28 @@ static void layout_sort_button_press_cb(GtkWidget *widget, gpointer data)
 	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, 0, etime);
 }
 
-static GtkWidget *layout_sort_button(LayoutWindow *lw)
+static GtkWidget *layout_sort_button(LayoutWindow *lw, GtkWidget *box)
 {
 	GtkWidget *button;
+	GtkWidget *frame;
+	GtkWidget *image;
 
+	frame = gtk_frame_new(NULL);
+	DEBUG_NAME(frame);
+	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
+	gtk_box_pack_start(GTK_BOX(box), frame, FALSE, FALSE, 0);
+	gtk_widget_show(frame);
+
+	image = gtk_image_new_from_icon_name("pan-down", GTK_ICON_SIZE_BUTTON);
 	button = gtk_button_new_with_label(sort_type_get_text(lw->sort_method));
-	DEBUG_NAME(button);
+	gtk_button_set_image(GTK_BUTTON(button), image);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(layout_sort_button_press_cb), lw);
 	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
+	gtk_button_set_image_position(GTK_BUTTON(button), GTK_POS_RIGHT);
+
+	gtk_container_add(GTK_CONTAINER(frame), button);
+	gtk_widget_show(button);
 
 	return button;
 }
@@ -602,7 +615,7 @@ static GtkWidget *layout_zoom_button(LayoutWindow *lw, GtkWidget *box, gint size
 {
 	GtkWidget *button;
 	GtkWidget *frame;
-
+	GtkWidget *image;
 
 	frame = gtk_frame_new(NULL);
 	DEBUG_NAME(frame);
@@ -613,10 +626,13 @@ static GtkWidget *layout_zoom_button(LayoutWindow *lw, GtkWidget *box, gint size
 
 	gtk_widget_show(frame);
 
+	image = gtk_image_new_from_icon_name("pan-down", GTK_ICON_SIZE_BUTTON);
 	button = gtk_button_new_with_label("1:1");
+	gtk_button_set_image(GTK_BUTTON(button), image);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(layout_zoom_button_press_cb), lw);
 	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
+	gtk_button_set_image_position(GTK_BUTTON(button), GTK_POS_RIGHT);
 
 	gtk_container_add(GTK_CONTAINER(frame), button);
 	gtk_widget_show(button);
@@ -660,6 +676,10 @@ void layout_status_update_progress(LayoutWindow *lw, gdouble val, const gchar *t
 void layout_status_update_info(LayoutWindow *lw, const gchar *text)
 {
 	gchar *buf = NULL;
+	gint hrs;
+	gint min;
+	gdouble sec;
+	GString *delay;
 
 	if (!layout_valid(&lw)) return;
 
@@ -674,22 +694,40 @@ void layout_status_update_info(LayoutWindow *lw, const gchar *text)
 			{
 			guint s;
 			gint64 s_bytes = 0;
-			const gchar *ss;
+			gchar *ss;
 
 			if (layout_image_slideshow_active(lw))
 				{
+
 				if (!layout_image_slideshow_paused(lw))
 					{
-					ss = _(" Slideshow");
+					delay = g_string_new(_(" Slideshow ["));
 					}
 				else
 					{
-					ss = _(" Paused");
+					delay = g_string_new(_(" Paused ["));
 					}
+				hrs = options->slideshow.delay / (36000);
+				min = (options->slideshow.delay -(36000 * hrs))/600;
+				sec = (gdouble)(options->slideshow.delay -(36000 * hrs)-(min * 600)) / 10;
+
+				if (hrs > 0)
+					{
+					g_string_append_printf(delay, "%dh ", hrs);
+					}
+				if (min > 0)
+					{
+					g_string_append_printf(delay, "%dm ", min);
+					}
+				g_string_append_printf(delay, "%.1fs]", sec);
+
+				ss = g_strdup(delay->str);
+
+				g_string_free(delay, TRUE);
 				}
 			else
 				{
-				ss = "";
+				ss = g_strdup("");
 				}
 
 			s = layout_selection_count(lw, &s_bytes);
@@ -703,16 +741,19 @@ void layout_status_update_info(LayoutWindow *lw, const gchar *text)
 				buf = g_strdup_printf(_("%s, %d files (%s, %d)%s"), b, n, sb, s, ss);
 				g_free(b);
 				g_free(sb);
+				g_free(ss);
 				}
 			else if (n > 0)
 				{
 				gchar *b = text_from_size_abrev(n_bytes);
 				buf = g_strdup_printf(_("%s, %d files%s"), b, n, ss);
 				g_free(b);
+				g_free(ss);
 				}
 			else
 				{
 				buf = g_strdup_printf(_("%d files%s"), n, ss);
+				g_free(ss);
 				}
 
 			text = buf;
@@ -824,6 +865,7 @@ static GtkWidget *layout_status_label(gchar *text, GtkWidget *box, gboolean star
 	gtk_widget_show(frame);
 
 	label = gtk_label_new(text ? text : "");
+	gtk_label_set_ellipsize(GTK_LABEL(label), PANGO_ELLIPSIZE_END);
 	gtk_container_add(GTK_CONTAINER(frame), label);
 	gtk_widget_show(label);
 
@@ -872,14 +914,13 @@ static void layout_status_setup(LayoutWindow *lw, GtkWidget *box, gboolean small
 	gtk_box_pack_start(GTK_BOX(hbox), lw->info_progress_bar, FALSE, FALSE, 0);
 	gtk_widget_show(lw->info_progress_bar);
 
-	lw->info_sort = layout_sort_button(lw);
+	lw->info_sort = layout_sort_button(lw, hbox);
 	gtk_widget_set_tooltip_text(GTK_WIDGET(lw->info_sort), _("Select sort order"));
-	gtk_box_pack_start(GTK_BOX(hbox), lw->info_sort, FALSE, FALSE, 0);
 	gtk_widget_show(lw->info_sort);
 
 	lw->info_status = layout_status_label(NULL, lw->info_box, TRUE, 0, (!small_format));
 	DEBUG_NAME(lw->info_status);
-	gtk_widget_set_tooltip_text(GTK_WIDGET(lw->info_status), _("Folder contents (files selected)"));
+	gtk_widget_set_tooltip_text(GTK_WIDGET(lw->info_status), _("Folder contents (files selected)\nSlideshow [time interval]"));
 
 	if (small_format)
 		{
@@ -1086,6 +1127,16 @@ void layout_select_invert(LayoutWindow *lw)
 	if (lw->vf) vf_select_invert(lw->vf);
 }
 
+void layout_select_list(LayoutWindow *lw, GList *list)
+{
+	if (!layout_valid(&lw)) return;
+
+	if (lw->vf)
+		{
+		vf_select_list(lw->vf, list);
+		}
+}
+
 void layout_mark_to_selection(LayoutWindow *lw, gint mark, MarkToSelectionMode mode)
 {
 	if (!layout_valid(&lw)) return;
@@ -1316,8 +1367,7 @@ void layout_sort_set(LayoutWindow *lw, SortType type, gboolean ascend)
 	lw->sort_method = type;
 	lw->sort_ascend = ascend;
 
-	if (lw->info_sort) gtk_label_set_text(GTK_LABEL(gtk_bin_get_child(GTK_BIN(lw->info_sort))),
-					      sort_type_get_text(type));
+	if (lw->info_sort) gtk_button_set_label(GTK_BUTTON(lw->info_sort), sort_type_get_text(type));
 	layout_list_sync_sort(lw);
 }
 
@@ -2410,8 +2460,18 @@ void layout_sync_options_with_current_state(LayoutWindow *lw)
 
 #ifdef GDK_WINDOWING_X11
 #if GTK_CHECK_VERSION(3,10,0)
-	window = gtk_widget_get_window(GTK_WIDGET(lw->window));
-	lw->options.workspace = gdk_x11_window_get_desktop(window);
+	GdkDisplay *display;
+
+	if (options->save_window_workspace)
+		{
+		display = gdk_display_get_default();
+
+		if (GDK_IS_X11_DISPLAY(display))
+			{
+			window = gtk_widget_get_window(GTK_WIDGET(lw->window));
+			lw->options.workspace = gdk_x11_window_get_desktop(window);
+			}
+		}
 #endif
 #endif
 	return;
@@ -2423,7 +2483,7 @@ void layout_apply_options(LayoutWindow *lw, LayoutOptions *lop)
 	gboolean refresh_lists;
 
 	if (!layout_valid(&lw)) return;
-/* FIXME: add other options too */
+/** @FIXME add other options too */
 
 	refresh_style = (lop->style != lw->options.style || strcmp(lop->order, lw->options.order) != 0);
 	refresh_lists = (lop->show_directory_date != lw->options.show_directory_date);
@@ -2452,9 +2512,6 @@ void save_layout(LayoutWindow *lw)
 
 void layout_close(LayoutWindow *lw)
 {
-	GList *list;
-	LayoutWindow *tmp_lw;
-
 	if (layout_window_list && layout_window_list->next)
 		{
 		save_layout(lw);
@@ -2520,23 +2577,31 @@ gboolean release_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
 	return defined_mouse_buttons(widget, event, data);
 }
 
-#ifdef GDK_WINDOWING_X11
-#if GTK_CHECK_VERSION(3,10,0)
 static gboolean move_window_to_workspace_cb(gpointer data)
 {
+#ifdef GDK_WINDOWING_X11
+#if GTK_CHECK_VERSION(3,10,0)
 	LayoutWindow *lw = data;
 	GdkWindow *window;
+	GdkDisplay *display;
 
-	if (lw->options.workspace != -1)
+	if (options->save_window_workspace)
 		{
-		window = gtk_widget_get_window(GTK_WIDGET(lw->window));
-		gdk_x11_window_move_to_desktop(window, lw->options.workspace);
-		}
+		display = gdk_display_get_default();
 
+		if (GDK_IS_X11_DISPLAY(display))
+			{
+			if (lw->options.workspace != -1)
+				{
+				window = gtk_widget_get_window(GTK_WIDGET(lw->window));
+				gdk_x11_window_move_to_desktop(window, lw->options.workspace);
+				}
+			}
+		}
+#endif
+#endif
 	return FALSE;
 }
-#endif
-#endif
 
 LayoutWindow *layout_new_with_geometry(FileData *dir_fd, LayoutOptions *lop,
 				       const gchar *geometry)
@@ -2545,6 +2610,7 @@ LayoutWindow *layout_new_with_geometry(FileData *dir_fd, LayoutOptions *lop,
 	GdkGeometry hint;
 	GdkWindowHints hint_mask;
 	Histogram *histogram;
+	gchar *default_path;
 
 	DEBUG_1("%s layout_new: start", get_exec_time());
 	lw = g_new0(LayoutWindow, 1);
@@ -2572,11 +2638,16 @@ LayoutWindow *layout_new_with_geometry(FileData *dir_fd, LayoutOptions *lop,
 
 	/* divider positions */
 
+	default_path = g_build_filename(get_rc_dir(), DEFAULT_WINDOW_LAYOUT, NULL);
+
 	if (!options->save_window_positions)
 		{
-		lw->options.main_window.hdivider_pos = MAIN_WINDOW_DIV_HPOS;
-		lw->options.main_window.vdivider_pos = MAIN_WINDOW_DIV_VPOS;
-		lw->options.float_window.vdivider_pos = MAIN_WINDOW_DIV_VPOS;
+		if (!isfile(default_path))
+			{
+			lw->options.main_window.hdivider_pos = MAIN_WINDOW_DIV_HPOS;
+			lw->options.main_window.vdivider_pos = MAIN_WINDOW_DIV_VPOS;
+			lw->options.float_window.vdivider_pos = MAIN_WINDOW_DIV_VPOS;
+			}
 		}
 
 	/* window */
@@ -2604,7 +2675,7 @@ LayoutWindow *layout_new_with_geometry(FileData *dir_fd, LayoutOptions *lop,
 	gtk_window_set_geometry_hints(GTK_WINDOW(lw->window), NULL, &hint,
 				      GDK_HINT_MIN_SIZE | GDK_HINT_BASE_SIZE | hint_mask);
 
-	if (options->save_window_positions)
+	if (options->save_window_positions || isfile(default_path))
 		{
 		gtk_window_set_default_size(GTK_WINDOW(lw->window), lw->options.main_window.w, lw->options.main_window.h);
 //		if (!layout_window_list)
@@ -2612,17 +2683,15 @@ LayoutWindow *layout_new_with_geometry(FileData *dir_fd, LayoutOptions *lop,
 		gtk_window_move(GTK_WINDOW(lw->window), lw->options.main_window.x, lw->options.main_window.y);
 		if (lw->options.main_window.maximized) gtk_window_maximize(GTK_WINDOW(lw->window));
 //			}
-#ifdef GDK_WINDOWING_X11
-#if GTK_CHECK_VERSION(3,10,0)
+
 		g_idle_add(move_window_to_workspace_cb, lw);
-#endif
-#endif
 		}
 	else
 		{
 		gtk_window_set_default_size(GTK_WINDOW(lw->window), MAINWINDOW_DEF_WIDTH, MAINWINDOW_DEF_HEIGHT);
 		}
 
+	g_free(default_path);
 	g_signal_connect(G_OBJECT(lw->window), "delete_event",
 			 G_CALLBACK(layout_delete_cb), lw);
 
@@ -2656,7 +2725,7 @@ LayoutWindow *layout_new_with_geometry(FileData *dir_fd, LayoutOptions *lop,
 
 		pixbuf = pixbuf_inline(PIXBUF_INLINE_LOGO);
 
-		/* FIXME: the zoom value set here is the value, which is then copied again and again
+		/** @FIXME the zoom value set here is the value, which is then copied again and again
 		   in "Leave Zoom at previous setting" mode. This is not ideal.  */
 		image_change_pixbuf(lw->image, pixbuf, 0.0, FALSE);
 		g_object_unref(pixbuf);
@@ -2703,7 +2772,6 @@ void layout_write_attributes(LayoutOptions *layout, GString *outstr, gint indent
 	WRITE_NL(); WRITE_BOOL(*layout, show_thumbnails);
 	WRITE_NL(); WRITE_BOOL(*layout, show_directory_date);
 	WRITE_NL(); WRITE_CHAR(*layout, home_path);
-	WRITE_NL(); WRITE_CHAR(*layout, last_path);
 	WRITE_NL(); WRITE_UINT(*layout, startup_path);
 	WRITE_SEPARATOR();
 
@@ -2756,6 +2824,12 @@ void layout_write_attributes(LayoutOptions *layout, GString *outstr, gint indent
 	WRITE_NL(); WRITE_INT(*layout, log_window.w);
 	WRITE_NL(); WRITE_INT(*layout, log_window.h);
 
+	WRITE_NL(); WRITE_INT(*layout, preferences_window.x);
+	WRITE_NL(); WRITE_INT(*layout, preferences_window.y);
+	WRITE_NL(); WRITE_INT(*layout, preferences_window.w);
+	WRITE_NL(); WRITE_INT(*layout, preferences_window.h);
+	WRITE_NL(); WRITE_INT(*layout, preferences_window.page_number);
+
 	WRITE_NL(); WRITE_INT(*layout, search_window.x);
 	WRITE_NL(); WRITE_INT(*layout, search_window.y);
 	WRITE_NL(); WRITE_INT(*layout, search_window.w);
@@ -2765,6 +2839,11 @@ void layout_write_attributes(LayoutOptions *layout, GString *outstr, gint indent
 	WRITE_NL(); WRITE_INT(*layout, dupe_window.y);
 	WRITE_NL(); WRITE_INT(*layout, dupe_window.w);
 	WRITE_NL(); WRITE_INT(*layout, dupe_window.h);
+
+	WRITE_NL(); WRITE_INT(*layout, advanced_exif_window.x);
+	WRITE_NL(); WRITE_INT(*layout, advanced_exif_window.y);
+	WRITE_NL(); WRITE_INT(*layout, advanced_exif_window.w);
+	WRITE_NL(); WRITE_INT(*layout, advanced_exif_window.h);
 	WRITE_SEPARATOR();
 
 	WRITE_NL(); WRITE_BOOL(*layout, animate);
@@ -2815,7 +2894,6 @@ void layout_load_attributes(LayoutOptions *layout, const gchar **attribute_names
 		if (READ_BOOL(*layout, show_thumbnails)) continue;
 		if (READ_BOOL(*layout, show_directory_date)) continue;
 		if (READ_CHAR(*layout, home_path)) continue;
-		if (READ_CHAR(*layout, last_path)) continue;
 		if (READ_UINT_CLAMP(*layout, startup_path, 0, STARTUP_PATH_HOME)) continue;
 
 		/* window positions */
@@ -2860,6 +2938,12 @@ void layout_load_attributes(LayoutOptions *layout, const gchar **attribute_names
 		if (READ_INT(*layout, log_window.w)) continue;
 		if (READ_INT(*layout, log_window.h)) continue;
 
+		if (READ_INT(*layout, preferences_window.x)) continue;
+		if (READ_INT(*layout, preferences_window.y)) continue;
+		if (READ_INT(*layout, preferences_window.w)) continue;
+		if (READ_INT(*layout, preferences_window.h)) continue;
+		if (READ_INT(*layout, preferences_window.page_number)) continue;
+
 		if (READ_INT(*layout, search_window.x)) continue;
 		if (READ_INT(*layout, search_window.y)) continue;
 		if (READ_INT(*layout, search_window.w)) continue;
@@ -2870,6 +2954,11 @@ void layout_load_attributes(LayoutOptions *layout, const gchar **attribute_names
 		if (READ_INT(*layout, dupe_window.w)) continue;
 		if (READ_INT(*layout, dupe_window.h)) continue;
 
+		if (READ_INT(*layout, advanced_exif_window.x)) continue;
+		if (READ_INT(*layout, advanced_exif_window.y)) continue;
+		if (READ_INT(*layout, advanced_exif_window.w)) continue;
+		if (READ_INT(*layout, advanced_exif_window.h)) continue;
+
 		if (READ_BOOL(*layout, animate)) continue;
 		if (READ_INT(*layout, workspace)) continue;
 
@@ -2891,7 +2980,7 @@ static void layout_config_startup_path(LayoutOptions *lop, gchar **path)
 	switch (lop->startup_path)
 		{
 		case STARTUP_PATH_LAST:
-			*path = (lop->last_path && isdir(lop->last_path)) ? g_strdup(lop->last_path) : get_current_dir();
+			*path = (history_list_find_last_path_by_key("path_list") && isdir(history_list_find_last_path_by_key("path_list"))) ? g_strdup(history_list_find_last_path_by_key("path_list")) : get_current_dir();
 			break;
 		case STARTUP_PATH_HOME:
 			*path = (lop->home_path && isdir(lop->home_path)) ? g_strdup(lop->home_path) : g_strdup(homedir());
@@ -2981,5 +3070,30 @@ void layout_update_from_config(LayoutWindow *lw, const gchar **attribute_names,
 	free_layout_options_content(&lop);
 }
 
+LayoutWindow *layout_new_from_default()
+{
+	LayoutWindow *lw;
+	GList *work;
+	gboolean success;
+	gchar *default_path;
+
+	default_path = g_build_filename(get_rc_dir(), DEFAULT_WINDOW_LAYOUT, NULL);
+	success = load_config_from_file(default_path, TRUE);
+	g_free(default_path);
+
+	if (success)
+		{
+		work = g_list_last(layout_window_list);
+		lw = work->data;
+		g_free(lw->options.id);
+		lw->options.id = g_strdup(layout_get_unique_id());
+		}
+	else
+		{
+		layout_new_from_config(NULL, NULL, TRUE);
+		}
+	return lw;
+}
+
 
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
