@@ -583,6 +583,17 @@ static void li_pop_menu_copy_path_unquoted_cb(GtkWidget *widget, gpointer data)
 	file_util_copy_path_to_clipboard(layout_image_get_fd(lw), FALSE);
 }
 
+static void li_pop_menu_copy_image_cb(GtkWidget *widget, gpointer data)
+{
+	LayoutWindow *lw = data;
+	ImageWindow *imd = lw->image;
+
+	GdkPixbuf *pixbuf;
+	pixbuf = image_get_pixbuf(imd);
+	if (!pixbuf) return;
+	gtk_clipboard_set_image(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD), pixbuf);
+}
+
 static void li_pop_menu_move_cb(GtkWidget *widget, gpointer data)
 {
 	LayoutWindow *lw = data;
@@ -670,6 +681,27 @@ static void li_set_layout_path_cb(GtkWidget *widget, gpointer data)
 	if (fd) layout_set_fd(lw, fd);
 }
 
+static void li_open_archive_cb(GtkWidget *widget, gpointer data)
+{
+	LayoutWindow *lw = data;
+	LayoutWindow *lw_new;
+	gchar *dest_dir;
+
+	if (!layout_valid(&lw)) return;
+
+	dest_dir = open_archive(layout_image_get_fd(lw));
+	if (dest_dir)
+		{
+		lw_new = layout_new_from_default();
+		layout_set_path(lw_new, dest_dir);
+		g_free(dest_dir);
+		}
+	else
+		{
+		warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GTK_STOCK_DIALOG_WARNING, NULL);
+		}
+}
+
 static gboolean li_check_if_current_path(LayoutWindow *lw, const gchar *path)
 {
 	gchar *dirname;
@@ -734,16 +766,23 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 	const gchar *path;
 	gboolean fullscreen;
 	GList *editmenu_fd_list;
+	GtkAccelGroup *accel_group;
 
 	path = layout_image_get_path(lw);
 	fullscreen = layout_image_full_screen_active(lw);
 
 	menu = popup_menu_short_lived();
 
+	accel_group = gtk_accel_group_new();
+	gtk_menu_set_accel_group(GTK_MENU(menu), accel_group);
+
+	g_object_set_data(G_OBJECT(menu), "window_keys", NULL);
+	g_object_set_data(G_OBJECT(menu), "accel_group", accel_group);
+
 	menu_item_add_stock(menu, _("Zoom _in"), GTK_STOCK_ZOOM_IN, G_CALLBACK(li_pop_menu_zoom_in_cb), lw);
 	menu_item_add_stock(menu, _("Zoom _out"), GTK_STOCK_ZOOM_OUT, G_CALLBACK(li_pop_menu_zoom_out_cb), lw);
 	menu_item_add_stock(menu, _("Zoom _1:1"), GTK_STOCK_ZOOM_100, G_CALLBACK(li_pop_menu_zoom_1_1_cb), lw);
-	menu_item_add_stock(menu, _("Fit image to _window"), GTK_STOCK_ZOOM_FIT, G_CALLBACK(li_pop_menu_zoom_fit_cb), lw);
+	menu_item_add_stock(menu, _("Zoom to fit"), GTK_STOCK_ZOOM_FIT, G_CALLBACK(li_pop_menu_zoom_fit_cb), lw);
 	menu_item_add_divider(menu);
 
 	editmenu_fd_list = layout_image_get_fd_list(lw);
@@ -763,6 +802,12 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 	item = menu_item_add(menu, _("_Go to directory view"), G_CALLBACK(li_set_layout_path_cb), lw);
 	if (!path || li_check_if_current_path(lw, path)) gtk_widget_set_sensitive(item, FALSE);
 
+	item = menu_item_add_stock(menu, _("Open archive"), GTK_STOCK_OPEN, G_CALLBACK(li_open_archive_cb), lw);
+	if (!path || lw->image->image_fd->format_class != FORMAT_CLASS_ARCHIVE)
+		{
+		gtk_widget_set_sensitive(item, FALSE);
+		}
+
 	menu_item_add_divider(menu);
 
 	item = menu_item_add_stock(menu, _("_Copy..."), GTK_STOCK_COPY, G_CALLBACK(li_pop_menu_copy_cb), lw);
@@ -771,8 +816,9 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 	if (!path) gtk_widget_set_sensitive(item, FALSE);
 	item = menu_item_add(menu, _("_Rename..."), G_CALLBACK(li_pop_menu_rename_cb), lw);
 	if (!path) gtk_widget_set_sensitive(item, FALSE);
-	item = menu_item_add(menu, _("_Copy path"), G_CALLBACK(li_pop_menu_copy_path_cb), lw);
-	item = menu_item_add(menu, _("_Copy path unquoted"), G_CALLBACK(li_pop_menu_copy_path_unquoted_cb), lw);
+	item = menu_item_add(menu, _("_Copy path to clipboard"), G_CALLBACK(li_pop_menu_copy_path_cb), lw);
+	item = menu_item_add(menu, _("_Copy path unquoted to clipboard"), G_CALLBACK(li_pop_menu_copy_path_unquoted_cb), lw);
+	item = menu_item_add(menu, _("Copy _image to clipboard"), G_CALLBACK(li_pop_menu_copy_image_cb), lw);
 	if (!path) gtk_widget_set_sensitive(item, FALSE);
 	menu_item_add_divider(menu);
 
@@ -795,7 +841,7 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 
 	if (layout_image_slideshow_active(lw))
 		{
-		menu_item_add(menu, _("_Stop slideshow"), G_CALLBACK(li_pop_menu_slide_stop_cb), lw);
+		menu_item_add(menu, _("Toggle _slideshow"), G_CALLBACK(li_pop_menu_slide_stop_cb), lw);
 		if (layout_image_slideshow_paused(lw))
 			{
 			item = menu_item_add(menu, _("Continue slides_how"),
@@ -809,7 +855,7 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 		}
 	else
 		{
-		menu_item_add(menu, _("_Start slideshow"), G_CALLBACK(li_pop_menu_slide_start_cb), lw);
+		menu_item_add(menu, _("Toggle _slideshow"), G_CALLBACK(li_pop_menu_slide_start_cb), lw);
 		item = menu_item_add(menu, _("Pause slides_how"), G_CALLBACK(li_pop_menu_slide_pause_cb), lw);
 		gtk_widget_set_sensitive(item, FALSE);
 		}
@@ -823,7 +869,7 @@ static GtkWidget *layout_image_pop_menu(LayoutWindow *lw)
 		menu_item_add(menu, _("Exit _full screen"), G_CALLBACK(li_pop_menu_full_screen_cb), lw);
 		}
 
-	menu_item_add_check(menu, _("_Animate"), lw->options.animate, G_CALLBACK(li_pop_menu_animate_cb), lw);
+	menu_item_add_check(menu, _("GIF _animation"), lw->options.animate, G_CALLBACK(li_pop_menu_animate_cb), lw);
 
 	menu_item_add_divider(menu);
 
@@ -1267,7 +1313,14 @@ void layout_image_reset_orientation(LayoutWindow *lw)
 
 	if (options->image.exif_rotate_enable)
 		{
-		imd->orientation = metadata_read_int(imd->image_fd, ORIENTATION_KEY, EXIF_ORIENTATION_TOP_LEFT);
+		if (g_strcmp0(imd->image_fd->format_name, "heif") != 0)
+			{
+			imd->orientation = metadata_read_int(imd->image_fd, ORIENTATION_KEY, EXIF_ORIENTATION_TOP_LEFT);
+			}
+		else
+			{
+			imd->orientation = EXIF_ORIENTATION_TOP_LEFT;
+			}
 		}
 	else
 		{
@@ -1606,7 +1659,12 @@ void layout_image_next(LayoutWindow *lw)
 			if (y->next)
 				layout_image_set_index(lw, GPOINTER_TO_INT(y->next->data));
 			else
-				layout_image_set_index(lw, GPOINTER_TO_INT(x->data));
+				{
+				if (options->circular_selection_lists)
+					{
+					layout_image_set_index(lw, GPOINTER_TO_INT(x->data));
+					}
+				}
 			}
 		while (x)
 			x = g_list_remove(x, x->data);
@@ -1679,7 +1737,12 @@ void layout_image_prev(LayoutWindow *lw)
 			if (y->prev)
 				layout_image_set_index(lw, GPOINTER_TO_INT(y->prev->data));
 			else
-				layout_image_set_index(lw, GPOINTER_TO_INT(last->data));
+				{
+				if (options->circular_selection_lists)
+					{
+					layout_image_set_index(lw, GPOINTER_TO_INT(last->data));
+					}
+				}
 			}
 		while (x)
 			x = g_list_remove(x, x->data);
@@ -1814,11 +1877,27 @@ static void layout_image_button_cb(ImageWindow *imd, GdkEventButton *event, gpoi
 {
 	LayoutWindow *lw = data;
 	GtkWidget *menu;
+	LayoutWindow *lw_new;
+	gchar *dest_dir;
 
 	switch (event->button)
 		{
 		case MOUSE_BUTTON_LEFT:
-			if (options->image_l_click_video && options->image_l_click_video_editor && imd->image_fd && imd->image_fd->format_class == FORMAT_CLASS_VIDEO)
+			if (options->image_l_click_archive && imd-> image_fd && imd->image_fd->format_class == FORMAT_CLASS_ARCHIVE)
+				{
+				dest_dir = open_archive(imd->image_fd);
+				if (dest_dir)
+					{
+					lw_new = layout_new_from_default();
+					layout_set_path(lw_new, dest_dir);
+					g_free(dest_dir);
+					}
+				else
+					{
+					warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GTK_STOCK_DIALOG_WARNING, NULL);
+					}
+				}
+			else if (options->image_l_click_video && options->image_l_click_video_editor && imd-> image_fd && imd->image_fd->format_class == FORMAT_CLASS_VIDEO)
 				{
 				start_editor_from_file(options->image_l_click_video_editor, imd->image_fd);
 				}
@@ -2139,8 +2218,8 @@ void layout_image_activate(LayoutWindow *lw, gint i, gboolean force)
 
 	image_attach_window(lw->image, lw->window, NULL, GQ_APPNAME, FALSE);
 
-	/* do not hilight selected image in SPLIT_NONE */
-	/* maybe the image should be selected always and hilight should be controled by
+	/* do not highlight selected image in SPLIT_NONE */
+	/* maybe the image should be selected always and highlight should be controlled by
 	   another image option */
 	if (lw->split_mode != SPLIT_NONE)
 		image_select(lw->split_images[i], TRUE);
