@@ -328,7 +328,9 @@ gboolean metadata_write_perform(FileData *fd)
 		   (we can't wait until the sidecar is discovered by directory scanning because
 		    exif_read_fd is called before that and it would read the main file only and
 		    store the metadata in the cache)
-		    FIXME: this does not catch new sidecars created by independent external programs
+		*/
+		/**
+		@FIXME this does not catch new sidecars created by independent external programs
 		*/
 		file_data_unref(file_data_new_group(fd->change->dest));
 
@@ -670,7 +672,7 @@ GList *metadata_read_list(FileData *fd, const gchar *key, MetadataFormat format)
 	const GList *cache_entry;
 	if (!fd) return NULL;
 
-	/* unwritten data overide everything */
+	/* unwritten data override everything */
 	if (fd->modified_xmp && format == METADATA_PLAIN)
 		{
 	        list = g_hash_table_lookup(fd->modified_xmp, key);
@@ -927,7 +929,7 @@ gboolean metadata_append_list(FileData *fd, const gchar *key, const GList *value
 }
 
 /**
- * \see find_string_in_list
+ * @see find_string_in_list
  */
 gchar *find_string_in_list_utf8nocase(GList *list, const gchar *string)
 {
@@ -960,7 +962,7 @@ gchar *find_string_in_list_utf8nocase(GList *list, const gchar *string)
 }
 
 /**
- * \see find_string_in_list
+ * @see find_string_in_list
  */
 gchar *find_string_in_list_utf8case(GList *list, const gchar *string)
 {
@@ -978,18 +980,18 @@ gchar *find_string_in_list_utf8case(GList *list, const gchar *string)
 } // gchar *find_string_in_list_utf...
 
 /**
- * \brief Find a existent string in a list.
+ * @brief Find a existent string in a list.
  *
  * This is a switch between find_string_in_list_utf8case and
  * find_string_in_list_utf8nocase to search with or without case for the
  * existence of a string.
  *
- * \param list The list to search in
- * \param string The string to search for
- * \return The string or NULL
+ * @param list The list to search in
+ * @param string The string to search for
+ * @return The string or NULL
  *
- * \see find_string_in_list_utf8case
- * \see find_string_in_list_utf8nocase
+ * @see find_string_in_list_utf8case
+ * @see find_string_in_list_utf8nocase
  */
 gchar *find_string_in_list(GList *list, const gchar *string)
 {
@@ -1045,7 +1047,7 @@ GList *string_to_keywords_list(const gchar *text)
 
 gboolean meta_data_get_keyword_mark(FileData *fd, gint n, gpointer data)
 {
-	/* FIXME: do not use global keyword_tree */
+	/** @FIXME do not use global keyword_tree */
 	GList *path = data;
 	GList *keywords;
 	gboolean found = FALSE;
