@@ -64,6 +64,7 @@ ConfOptions *init_options(ConfOptions *options)
 
 	options->save_window_positions = TRUE;
 	options->use_saved_window_positions_for_new_windows = FALSE;
+	options->save_window_workspace = FALSE;
 	options->tools_restore_state = TRUE;
 	options->save_dialog_window_positions = FALSE;
 	options->show_window_ids = FALSE;
@@ -105,7 +106,6 @@ ConfOptions *init_options(ConfOptions *options)
 	options->image.alpha_color_2.blue = 0x006666;
 	options->image.enable_read_ahead = TRUE;
 	options->image.exif_rotate_enable = TRUE;
-	options->image.exif_proof_rotate_enable = TRUE;
 	options->image.fit_window_to_image = FALSE;
 	options->image.limit_autofit_size = FALSE;
 	options->image.limit_window_size = TRUE;
@@ -122,6 +122,8 @@ ConfOptions *init_options(ConfOptions *options)
 	options->image.zoom_mode = ZOOM_RESET_NONE;
 	options->image.zoom_quality = GDK_INTERP_BILINEAR;
 	options->image.zoom_to_fit_allow_expand = FALSE;
+	options->image.zoom_style = ZOOM_GEOMETRIC;
+	options->image.tile_size = 128;
 
 	options->image_overlay.template_string = NULL;
 	options->image_overlay.x = 10;
@@ -139,6 +141,7 @@ ConfOptions *init_options(ConfOptions *options)
 	options->lazy_image_sync = FALSE;
 	options->mousewheel_scrolls = FALSE;
 	options->image_lm_click_nav = TRUE;
+	options->image_l_click_archive = FALSE;
 	options->image_l_click_video = FALSE;
 	options->image_l_click_video_editor = NULL;
 	options->open_recent_list_maxsize = 10;
@@ -179,14 +182,16 @@ ConfOptions *init_options(ConfOptions *options)
 	options->thumbnails.spec_standard = TRUE;
 	options->thumbnails.use_xvpics = TRUE;
 	options->thumbnails.use_exif = FALSE;
+	options->thumbnails.use_color_management = FALSE;
 	options->thumbnails.use_ft_metadata = TRUE;
 // 	options->thumbnails.use_ft_metadata_small = TRUE;
 	options->thumbnails.collection_preview = 20;
 
 	options->tree_descend_subdirs = FALSE;
 	options->view_dir_list_single_click_enter = TRUE;
+	options->circular_selection_lists = TRUE;
 	options->update_on_time_change = TRUE;
-	options->clipboard_selection = PRIMARY;
+	options->clipboard_selection = CLIPBOARD_BOTH;
 
 	options->stereo.fixed_w = 1920;
 	options->stereo.fixed_h = 1080;
@@ -196,7 +201,7 @@ ConfOptions *init_options(ConfOptions *options)
 	options->stereo.fixed_y2 = 1125;
 
 	options->log_window_lines = 1000;
-	options->log_window.line_wrap = TRUE;
+	options->log_window.line_wrap = FALSE;
 	options->log_window.paused = FALSE;
 	options->log_window.timer_data = FALSE;
 
@@ -211,6 +216,8 @@ ConfOptions *init_options(ConfOptions *options)
 	options->printer.image_text_position = 1;
 	options->printer.page_text_position = 3;
 
+	options->threads.duplicates = -1;
+
 	options->disabled_plugins = NULL;
 
 	options->mouse_button_8 = g_strdup("Back");
@@ -248,7 +255,7 @@ void setup_default_options(ConfOptions *options)
 		}
 
 	set_default_image_overlay_template_string(&options->image_overlay.template_string);
-	options->sidecar.ext = g_strdup(".jpg;%raw;.ufraw;.xmp;%unknown");
+	options->sidecar.ext = g_strdup(".jpg;%raw;.xmp;%unknown");
 
 	options->shell.path = g_strdup(GQ_DEFAULT_SHELL_PATH);
 	options->shell.options = g_strdup(GQ_DEFAULT_SHELL_OPTIONS);
@@ -309,6 +316,10 @@ LayoutOptions *init_layout_options(LayoutOptions *options)
 	options->search_window.h = 650;
 	options->search_window.x = 100;
 	options->search_window.y = 100;
+	options->advanced_exif_window.w = 900;
+	options->advanced_exif_window.h = 600;
+	options->advanced_exif_window.x = 0;
+	options->advanced_exif_window.y = 0;
 	options->folder_window.vdivider_pos = 100;
 	options->order = g_strdup("123");
 	options->show_directory_date = FALSE;
@@ -327,6 +338,8 @@ LayoutOptions *init_layout_options(LayoutOptions *options)
 	options->bars_state.hidden = FALSE;
 	options->log_window.w = 520;
 	options->log_window.h = 400;
+	options->preferences_window.w = 700;
+	options->preferences_window.h = 600;
 	options->split_pane_sync = FALSE;
 	options->workspace = -1;
 	return options;
