@@ -87,6 +87,53 @@ static GtkWidget *pan_popup_menu(PanWindow *pw);
 
 static void pan_window_dnd_init(PanWindow *pw);
 
+/**
+ * This array must be kept in sync with the contents of:\n
+ * @link pan_window_key_press_cb @endlink \n
+ * @link pan_popup_menu @endlink
+ *
+ * See also @link hard_coded_window_keys @endlink
+ **/
+hard_coded_window_keys pan_view_window_keys[] = {
+	{GDK_CONTROL_MASK, 'C', N_("Copy")},
+	{GDK_CONTROL_MASK, 'M', N_("Move")},
+	{GDK_CONTROL_MASK, 'R', N_("Rename")},
+	{GDK_CONTROL_MASK, 'D', N_("Move to Trash")},
+	{GDK_CONTROL_MASK, 'W', N_("Close window")},
+	{GDK_CONTROL_MASK, 'F', N_("Display Find search bar")},
+	{GDK_CONTROL_MASK, 'G', N_("Start search")},
+	{0, GDK_KEY_Escape, N_("Exit fullscreen")},
+	{0, GDK_KEY_Escape, N_("Hide Find search bar")},
+	{0, GDK_KEY_equal, N_("Zoom in")},
+	{0, GDK_KEY_plus, N_("Zoom in")},
+	{0, GDK_KEY_minus, N_("Zoom out")},
+	{0, GDK_KEY_Z, N_("Zoom 1:1")},
+	{0, GDK_KEY_1, N_("Zoom 1:1")},
+	{0, GDK_KEY_KP_Divide, N_("Zoom 1:1")},
+	{0, '2', N_("Zoom 2:1")},
+	{0, '3', N_("Zoom 3:1")},
+	{0, '4', N_("Zoom 4:1")},
+	{0, '7', N_("Zoom 1:4")},
+	{0, '8', N_("Zoom 1:3")},
+	{0, '9', N_("Zoom 1:2")},
+	{0, 'F', N_("Full screen")},
+	{0, 'V', N_("Full screen")},
+	{0, GDK_KEY_F11, N_("Full screen")},
+	{0, '/', N_("Display Find search bar")},
+	{0, GDK_KEY_Left, N_("Scroll left")},
+	{0, GDK_KEY_Right, N_("Scroll right")},
+	{0, GDK_KEY_Up, N_("Scroll up")},
+	{0, GDK_KEY_Down, N_("Scroll down")},
+	{GDK_SHIFT_MASK, GDK_KEY_Left, N_("Scroll left faster")},
+	{GDK_SHIFT_MASK, GDK_KEY_Right, N_("Scroll right faster")},
+	{GDK_SHIFT_MASK, GDK_KEY_Up, N_("Scroll up faster")},
+	{GDK_SHIFT_MASK, GDK_KEY_Down, N_("Scroll down faster")},
+	{0, GDK_KEY_Page_Up, N_("Scroll display half screen up")},
+	{0, GDK_KEY_Page_Down, N_("Scroll display half screen down")},
+	{0, GDK_KEY_Home, N_("Scroll display half screen left")},
+	{0, GDK_KEY_End, N_("Scroll display half screen right")},
+	{0, 0, NULL}
+};
 
 /*
  *-----------------------------------------------------------------------------
@@ -128,6 +175,7 @@ static void pan_queue_thumb_done_cb(ThumbLoader *tl, gpointer data)
 static void pan_queue_image_done_cb(ImageLoader *il, gpointer data)
 {
 	PanWindow *pw = data;
+	GdkPixbuf *rotated = NULL;
 
 	if (pw->queue_pi)
 		{
@@ -141,6 +189,28 @@ static void pan_queue_image_done_cb(ImageLoader *il, gpointer data)
 
 		if (pi->pixbuf) g_object_unref(pi->pixbuf);
 		pi->pixbuf = image_loader_get_pixbuf(pw->il);
+
+		if (pi->pixbuf && options->image.exif_rotate_enable)
+			{
+			if (!il->fd->exif_orientation)
+				{
+				if (g_strcmp0(il->fd->format_name, "heif") != 0)
+					{
+					il->fd->exif_orientation = metadata_read_int(il->fd, ORIENTATION_KEY, EXIF_ORIENTATION_TOP_LEFT);
+					}
+				else
+					{
+					il->fd->exif_orientation = EXIF_ORIENTATION_TOP_LEFT;
+					}
+				}
+
+			if (il->fd->exif_orientation != EXIF_ORIENTATION_TOP_LEFT)
+				{
+				rotated = pixbuf_apply_orientation(pi->pixbuf, il->fd->exif_orientation);
+				pi->pixbuf = rotated;
+				}
+			}
+
 		if (pi->pixbuf) g_object_ref(pi->pixbuf);
 
 		if (pi->pixbuf && pw->size != PAN_IMAGE_SIZE_100 &&
@@ -1867,7 +1937,7 @@ static void pan_window_new_real(FileData *dir_fd)
 	gtk_table_set_row_spacings(GTK_TABLE(table), 2);
 	gtk_table_set_col_spacings(GTK_TABLE(table), 2);
 
-	/* FIXME: pan view does not work correctly when renderer-clutter()
+	/** @FIXME pan view does not work correctly when renderer-clutter()
 	 * is used.
 	 */
 	gint temp = options->image.use_clutter_renderer;
@@ -1967,7 +2037,7 @@ static void pan_window_new_real(FileData *dir_fd)
 
 /*
  *-----------------------------------------------------------------------------
- * peformance warnings
+ * performance warnings
  *-----------------------------------------------------------------------------
  */
 
@@ -2217,7 +2287,7 @@ static void pan_info_toggle_exif_cb(GtkWidget *widget, gpointer data)
 	PanWindow *pw = data;
 
 	pw->info_includes_exif = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget));
-	/* fixme: sync info now */
+	/** @FIXME sync info now */
 }
 
 static void pan_info_toggle_image_cb(GtkWidget *widget, gpointer data)
@@ -2225,7 +2295,7 @@ static void pan_info_toggle_image_cb(GtkWidget *widget, gpointer data)
 	PanWindow *pw = data;
 
 	pw->info_image_size = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), INFO_IMAGE_SIZE_KEY));
-	/* fixme: sync info now */
+	/** @FIXME sync info now */
 }
 
 static void pan_fullscreen_cb(GtkWidget *widget, gpointer data)
@@ -2292,11 +2362,17 @@ static GtkWidget *pan_popup_menu(PanWindow *pw)
 	GtkWidget *item;
 	gboolean active, video;
 	GList *editmenu_fd_list;
+	GtkAccelGroup *accel_group;
 
 	active = (pw->click_pi != NULL);
 	video = (active && pw->click_pi->fd && pw->click_pi->fd->format_class == FORMAT_CLASS_VIDEO);
 
 	menu = popup_menu_short_lived();
+	accel_group = gtk_accel_group_new();
+	gtk_menu_set_accel_group(GTK_MENU(menu), accel_group);
+
+	g_object_set_data(G_OBJECT(menu), "window_keys", pan_view_window_keys);
+	g_object_set_data(G_OBJECT(menu), "accel_group", accel_group);
 
 	menu_item_add_stock_sensitive(menu, _("_Play"), GTK_STOCK_MEDIA_PLAY, video,
 			    G_CALLBACK(pan_play_cb), pw);
@@ -2329,9 +2405,9 @@ static GtkWidget *pan_popup_menu(PanWindow *pw)
 				G_CALLBACK(pan_move_cb), pw);
 	menu_item_add_sensitive(menu, _("_Rename..."), active,
 				G_CALLBACK(pan_rename_cb), pw);
-	menu_item_add_sensitive(menu, _("_Copy path"), active,
+	menu_item_add_sensitive(menu, _("_Copy path to clipboard"), active,
 				G_CALLBACK(pan_copy_path_cb), pw);
-	menu_item_add_sensitive(menu, _("_Copy path unquoted"), active,
+	menu_item_add_sensitive(menu, _("_Copy path unquoted to clipboard"), active,
 				G_CALLBACK(pan_copy_path_unquoted_cb), pw);
 
 	menu_item_add_divider(menu);
