@@ -38,6 +38,7 @@
 #include "slideshow.h"
 #include "ui_fileops.h"
 #include "rcfile.h"
+#include "view_file.h"
 
 #include <sys/socket.h>
 #include <sys/un.h>
@@ -72,6 +73,8 @@ struct _RemoteClient {
 typedef struct _RemoteData RemoteData;
 struct _RemoteData {
 	CollectionData *command_collection;
+	GList *file_list;
+	gboolean single_dir;
 };
 
 /* To enable file names containing newlines to be processed correctly,
@@ -127,7 +130,7 @@ static gboolean remote_server_client_cb(GIOChannel *source, GIOCondition conditi
 		gchar *buffer = NULL;
 		GError *error = NULL;
 		gsize termpos;
-		/* FIXME: it should be possible to terminate the command with a null character */
+		/** @FIXME it should be possible to terminate the command with a null character */
 		g_io_channel_set_line_term(source, "<gq_end_of_command>", -1);
 		while ((status = g_io_channel_read_line(source, &buffer, NULL, &termpos, &error)) == G_IO_STATUS_NORMAL)
 			{
@@ -261,7 +264,7 @@ static RemoteConnection *remote_server_open(const gchar *path)
 	addr.sun_family = AF_UNIX;
 	sun_path_len = MIN(strlen(path) + 1, UNIX_PATH_MAX);
 	strncpy(addr.sun_path, path, sun_path_len);
-	if (bind(fd, &addr, sizeof(addr)) == -1 ||
+	if (bind(fd, (struct sockaddr*)&addr, sizeof(addr)) == -1 ||
 	    listen(fd, REMOTE_SERVER_BACKLOG) == -1)
 		{
 		log_printf("error subscribing to socket: %s\n", strerror(errno));
@@ -310,7 +313,7 @@ static RemoteConnection *remote_client_open(const gchar *path)
 	addr.sun_family = AF_UNIX;
 	sun_path_len = MIN(strlen(path) + 1, UNIX_PATH_MAX);
 	strncpy(addr.sun_path, path, sun_path_len);
-	if (connect(fd, &addr, sizeof(addr)) == -1)
+	if (connect(fd, (struct sockaddr*)&addr, sizeof(addr)) == -1)
 		{
 		DEBUG_1("error connecting to socket: %s", strerror(errno));
 		close(fd);
@@ -457,7 +460,8 @@ static void gr_new_window(const gchar *text, GIOChannel *channel, gpointer data)
 
 	if (!layout_valid(&lw)) return;
 
-	lw_id = layout_menu_new_window(NULL, lw);
+	lw_id = layout_new_from_default();
+
 	layout_set_path(lw_id, pwd);
 }
 
@@ -518,7 +522,12 @@ static void gr_lw_id(const gchar *text, GIOChannel *channel, gpointer data)
 static void gr_slideshow_start_rec(const gchar *text, GIOChannel *channel, gpointer data)
 {
 	GList *list;
-	FileData *dir_fd = file_data_new_dir(text);
+	gchar *tilde_filename;
+
+	tilde_filename = expand_tilde(text);
+
+	FileData *dir_fd = file_data_new_dir(tilde_filename);
+	g_free(tilde_filename);
 
 	layout_valid(&lw_id);
 	list = filelist_recursive_full(dir_fd, lw_id->sort_method, lw_id->sort_ascend);
@@ -532,9 +541,13 @@ static void gr_slideshow_start_rec(const gchar *text, GIOChannel *channel, gpoin
 static void gr_cache_thumb(const gchar *text, GIOChannel *channel, gpointer data)
 {
 	if (!g_strcmp0(text, "clear"))
-		cache_maintain_home_remote(FALSE, TRUE);
+		{
+		cache_maintain_home_remote(FALSE, TRUE, NULL);
+		}
 	else if (!g_strcmp0(text, "clean"))
-		cache_maintain_home_remote(FALSE, FALSE);
+		{
+		cache_maintain_home_remote(FALSE, FALSE, NULL);
+		}
 }
 
 static void gr_cache_shared(const gchar *text, GIOChannel *channel, gpointer data)
@@ -547,29 +560,33 @@ static void gr_cache_shared(const gchar *text, GIOChannel *channel, gpointer dat
 
 static void gr_cache_metadata(const gchar *text, GIOChannel *channel, gpointer data)
 {
-	cache_maintain_home_remote(TRUE, FALSE);
+	cache_maintain_home_remote(TRUE, FALSE, NULL);
 }
 
 static void gr_cache_render(const gchar *text, GIOChannel *channel, gpointer data)
 {
-	cache_manager_render_remote(text, FALSE, FALSE);
+	cache_manager_render_remote(text, FALSE, FALSE, NULL);
 }
 
 static void gr_cache_render_recurse(const gchar *text, GIOChannel *channel, gpointer data)
 {
-	cache_manager_render_remote(text, TRUE, FALSE);
+	cache_manager_render_remote(text, TRUE, FALSE, NULL);
 }
 
 static void gr_cache_render_standard(const gchar *text, GIOChannel *channel, gpointer data)
 {
 	if(options->thumbnails.spec_standard)
-		cache_manager_render_remote(text, FALSE, TRUE);
+		{
+		cache_manager_render_remote(text, FALSE, TRUE, NULL);
+		}
 }
 
 static void gr_cache_render_standard_recurse(const gchar *text, GIOChannel *channel, gpointer data)
 {
 	if(options->thumbnails.spec_standard)
-		cache_manager_render_remote(text, TRUE, TRUE);
+		{
+		cache_manager_render_remote(text, TRUE, TRUE, NULL);
+		}
 }
 
 static void gr_slideshow_toggle(const gchar *text, GIOChannel *channel, gpointer data)
@@ -885,6 +902,9 @@ static void get_filelist(const gchar *text, GIOChannel *channel, gboolean recurs
 			case FORMAT_CLASS_DOCUMENT:
 				out_string = g_string_append(out_string, "    Class: Document");
 				break;
+			case FORMAT_CLASS_ARCHIVE:
+				out_string = g_string_append(out_string, "    Class: Archive");
+				break;
 			case FORMAT_CLASS_UNKNOWN:
 				out_string = g_string_append(out_string, "    Class: Unknown");
 				break;
@@ -1221,39 +1241,87 @@ static void gr_list_clear(const gchar *text, GIOChannel *channel, gpointer data)
 {
 	RemoteData *remote_data = data;
 
-	if (remote_data->command_collection)
-		{
-		collection_unref(remote_data->command_collection);
-		remote_data->command_collection = NULL;
-		}
+	remote_data->command_collection = NULL;
+	remote_data->file_list = NULL;
+	remote_data->single_dir = TRUE;
 }
 
 static void gr_list_add(const gchar *text, GIOChannel *channel, gpointer data)
 {
 	RemoteData *remote_data = data;
 	gboolean new = TRUE;
+	gchar *path = NULL;
+	FileData *fd;
+	FileData *first;
 
-	if (!remote_data->command_collection)
+	/* If there is a files list on the command line
+	 * check if they are all in the same folder
+	 */
+	if (remote_data->single_dir)
 		{
+		GList *work;
+		work = remote_data->file_list;
+		while (work && remote_data->single_dir)
+			{
+			gchar *dirname;
+			dirname = g_path_get_dirname(((FileData *)work->data)->path);
+			if (!path)
+				{
+				path = g_strdup(dirname);
+				}
+			else
+				{
+				if (g_strcmp0(path, dirname) != 0)
+					{
+					remote_data->single_dir = FALSE;
+					}
+				}
+			g_free(dirname);
+			work = work->next;
+			}
+		g_free(path);
+		}
+
+	gchar *pathname = g_path_get_dirname(text);
+	layout_set_path(lw_id, pathname);
+	g_free(pathname);
+
+	fd = file_data_new_simple(text);
+	remote_data->file_list = g_list_append(remote_data->file_list, fd);
+	file_data_unref(fd);
+
+	vf_select_none(lw_id->vf);
+	remote_data->file_list = g_list_reverse(remote_data->file_list);
+
+	layout_select_list(lw_id, remote_data->file_list);
+	layout_refresh(lw_id);
+	first = (FileData *)(g_list_first(vf_selection_get_list(lw_id->vf))->data);
+	layout_set_fd(lw_id, first);
+
 		CollectionData *cd;
+		CollectWindow *cw;
 
-		cd = collection_new("");
+	if (!remote_data->command_collection && !remote_data->single_dir)
+		{
+		cw = collection_window_new(NULL);
+		cd = cw->cd;
 
-		g_free(cd->path);
-		cd->path = NULL;
-		g_free(cd->name);
-		cd->name = g_strdup(_("Command line"));
+		collection_path_changed(cd);
 
 		remote_data->command_collection = cd;
 		}
-	else
+	else if (!remote_data->single_dir)
 		{
 		new = (!collection_get_first(remote_data->command_collection));
 		}
 
-	if (collection_add(remote_data->command_collection, file_data_new_group(text), FALSE) && new)
+	if (!remote_data->single_dir)
 		{
 		layout_image_set_collection(lw_id, remote_data->command_collection, collection_get_first(remote_data->command_collection));
+		if (collection_add(remote_data->command_collection, file_data_new_group(text), FALSE) && new)
+			{
+			layout_image_set_collection(lw_id, remote_data->command_collection, collection_get_first(remote_data->command_collection));
+			}
 		}
 }
 
@@ -1328,59 +1396,59 @@ struct _RemoteCommandEntry {
 
 static RemoteCommandEntry remote_commands[] = {
 	/* short, long                  callback,               extra, prefer, parameter, description */
-	{ "-n", "--next",               gr_image_next,          FALSE, FALSE, NULL, N_("next image") },
 	{ "-b", "--back",               gr_image_prev,          FALSE, FALSE, NULL, N_("previous image") },
-	{ NULL, "--first",              gr_image_first,         FALSE, FALSE, NULL, N_("first image") },
-	{ NULL, "--last",               gr_image_last,          FALSE, FALSE, NULL, N_("last image") },
-	{ "-f", "--fullscreen",         gr_fullscreen_toggle,   FALSE, TRUE,  NULL, N_("toggle full screen") },
-	{ "-fs","--fullscreen-start",   gr_fullscreen_start,    FALSE, FALSE, NULL, N_("start full screen") },
-	{ "-fS","--fullscreen-stop",    gr_fullscreen_stop,     FALSE, FALSE, NULL, N_("stop full screen") },
-	{ "-s", "--slideshow",          gr_slideshow_toggle,    FALSE, TRUE,  NULL, N_("toggle slide show") },
-	{ "-ss","--slideshow-start",    gr_slideshow_start,     FALSE, FALSE, NULL, N_("start slide show") },
-	{ "-sS","--slideshow-stop",     gr_slideshow_stop,      FALSE, FALSE, NULL, N_("stop slide show") },
-	{ NULL, "--slideshow-recurse:", gr_slideshow_start_rec, TRUE,  FALSE, N_("<FOLDER>"), N_("start recursive slide show in FOLDER") },
-	{ "-d", "--delay=",             gr_slideshow_delay,     TRUE,  FALSE, N_("<[H:][M:][N][.M]>"), N_("set slide show delay to Hrs Mins N.M seconds") },
-	{ "+t", "--tools-show",         gr_tools_show,          FALSE, TRUE,  NULL, N_("show tools") },
-	{ "-t", "--tools-hide",	        gr_tools_hide,          FALSE, TRUE,  NULL, N_("hide tools") },
-	{ "-q", "--quit",               gr_quit,                FALSE, FALSE, NULL, N_("quit") },
-	{ NULL, "--config-load:",       gr_config_load,         TRUE,  FALSE, N_("<FILE>|layout ID"), N_("load configuration from FILE") },
-	{ NULL, "--get-sidecars:",      gr_get_sidecars,        TRUE,  FALSE, N_("<FILE>"), N_("get list of sidecars of FILE") },
-	{ NULL, "--get-destination:",  	gr_get_destination,     TRUE,  FALSE, N_("<FILE>"), N_("get destination path of FILE") },
-	{ NULL, "file:",                gr_file_load,           TRUE,  FALSE, N_("<FILE>|<URL>"), N_("open FILE or URL, bring Geeqie window to the top") },
-	{ NULL, "--file:",              gr_file_load,           TRUE,  FALSE, N_("<FILE>|<URL>"), N_("open FILE or URL, bring Geeqie window to the top") },
-	{ NULL, "File:",                gr_file_load_no_raise,  TRUE,  FALSE, N_("<FILE>|<URL>"), N_("open FILE or URL, do not bring Geeqie window to the top") },
-	{ NULL, "--File:",              gr_file_load_no_raise,  TRUE,  FALSE, N_("<FILE>|<URL>"), N_("open FILE or URL, do not bring Geeqie window to the top") },
-	{ NULL, "--tell",               gr_file_tell,           FALSE, FALSE, NULL, N_("print filename [and Collection] of current image") },
-	{ NULL, "--pixel-info",         gr_pixel_info,          FALSE, FALSE, NULL, N_("print pixel info of mouse pointer on current image") },
-	{ NULL, "--get-rectangle",      gr_rectangle,           FALSE, FALSE, NULL, N_("get rectangle co-ordinates") },
-	{ NULL, "--get-render-intent",  gr_render_intent,       FALSE, FALSE, NULL, N_("get render intent") },
-	{ NULL, "--get-filelist:",      gr_filelist,            TRUE,  FALSE, N_("[<FOLDER>]"), N_("get list of files and class") },
-	{ NULL, "--get-filelist-recurse:", gr_filelist_recurse, TRUE,  FALSE, N_("[<FOLDER>]"), N_("get list of files and class recursive") },
-	{ NULL, "--get-collection:",    gr_collection,          TRUE,  FALSE, N_("<COLLECTION>"), N_("get collection content") },
-	{ NULL, "--get-collection-list", gr_collection_list,    FALSE, FALSE, NULL, N_("get collection list") },
-	{ NULL, "--get-file-info",      gr_file_info,           FALSE, FALSE, NULL, N_("get file info") },
-	{ NULL, "view:",                gr_file_view,           TRUE,  FALSE, N_("<FILE>"), N_("open FILE in new window") },
-	{ NULL, "--view:",              gr_file_view,           TRUE,  FALSE, N_("<FILE>"), N_("open FILE in new window") },
-	{ NULL, "--list-clear",         gr_list_clear,          FALSE, FALSE, NULL, N_("clear command line collection list") },
-	{ NULL, "--list-add:",          gr_list_add,            TRUE,  FALSE, N_("<FILE>"), N_("add FILE to command line collection list") },
-	{ NULL, "raise",                gr_raise,               FALSE, FALSE, NULL, N_("bring the Geeqie window to the top") },
-	{ NULL, "--raise",              gr_raise,               FALSE, FALSE, NULL, N_("bring the Geeqie window to the top") },
-	{ NULL, "--id:",                gr_lw_id,               TRUE, FALSE, N_("<ID>"), N_("window id for following commands") },
-	{ NULL, "--new-window",         gr_new_window,          FALSE, FALSE, NULL, N_("new window") },
 	{ NULL, "--close-window",       gr_close_window,        FALSE, FALSE, NULL, N_("close window") },
-	{ NULL, "--geometry=",          gr_geometry,            TRUE, FALSE, N_("<GEOMETRY>"), N_("set window geometry") },
-	{ "-ct:", "--cache-thumbs:",    gr_cache_thumb,         TRUE, FALSE, N_("clear|clean"), N_("clear or clean thumbnail cache") },
-	{ "-cs:", "--cache-shared:",    gr_cache_shared,        TRUE, FALSE, N_("clear|clean"), N_("clear or clean shared thumbnail cache") },
-	{ "-cm","--cache-metadata",      gr_cache_metadata,               FALSE, FALSE, NULL, N_("    clean the metadata cache") },
+	{ NULL, "--config-load: ",       gr_config_load,         TRUE,  FALSE, N_("<FILE>|layout ID"), N_(" load configuration from FILE") },
+	{ "-cm","--cache-metadata",      gr_cache_metadata,               FALSE, FALSE, NULL, N_("clean the metadata cache") },
 	{ "-cr:", "--cache-render:",    gr_cache_render,        TRUE, FALSE, N_("<folder>  "), N_(" render thumbnails") },
 	{ "-crr:", "--cache-render-recurse:", gr_cache_render_recurse, TRUE, FALSE, N_("<folder> "), N_("render thumbnails recursively") },
 	{ "-crs:", "--cache-render-shared:", gr_cache_render_standard, TRUE, FALSE, N_("<folder> "), N_(" render thumbnails (see Help)") },
 	{ "-crsr:", "--cache-render-shared-recurse:", gr_cache_render_standard_recurse, TRUE, FALSE, N_("<folder>"), N_(" render thumbnails recursively (see Help)") },
+	{ "-cs:", "--cache-shared:",    gr_cache_shared,        TRUE, FALSE, N_("clear|clean"), N_("clear or clean shared thumbnail cache") },
+	{ "-ct:", "--cache-thumbs:",    gr_cache_thumb,         TRUE, FALSE, N_("clear|clean"), N_("clear or clean thumbnail cache") },
+	{ "-d", "--delay=",             gr_slideshow_delay,     TRUE,  FALSE, N_("<[H:][M:][N][.M]>"), N_("set slide show delay to Hrs Mins N.M seconds") },
+	{ NULL, "--first",              gr_image_first,         FALSE, FALSE, NULL, N_("first image") },
+	{ "-f", "--fullscreen",         gr_fullscreen_toggle,   FALSE, TRUE,  NULL, N_("toggle full screen") },
+	{ NULL, "--file:",              gr_file_load,           TRUE,  FALSE, N_("<FILE>|<URL>"), N_("open FILE or URL, bring Geeqie window to the top") },
+	{ NULL, "file:",                gr_file_load,           TRUE,  FALSE, N_("<FILE>|<URL>"), N_("open FILE or URL, bring Geeqie window to the top") },
+	{ NULL, "--File:",              gr_file_load_no_raise,  TRUE,  FALSE, N_("<FILE>|<URL>"), N_("open FILE or URL, do not bring Geeqie window to the top") },
+	{ NULL, "File:",                gr_file_load_no_raise,  TRUE,  FALSE, N_("<FILE>|<URL>"), N_("open FILE or URL, do not bring Geeqie window to the top") },
+	{ "-fs","--fullscreen-start",   gr_fullscreen_start,    FALSE, FALSE, NULL, N_("start full screen") },
+	{ "-fS","--fullscreen-stop",    gr_fullscreen_stop,     FALSE, FALSE, NULL, N_("stop full screen") },
+	{ NULL, "--geometry=",          gr_geometry,            TRUE, FALSE, N_("<GEOMETRY>"), N_("set window geometry") },
+	{ NULL, "--get-collection:",    gr_collection,          TRUE,  FALSE, N_("<COLLECTION>"), N_("get collection content") },
+	{ NULL, "--get-collection-list", gr_collection_list,    FALSE, FALSE, NULL, N_("get collection list") },
+	{ NULL, "--get-destination:",  	gr_get_destination,     TRUE,  FALSE, N_("<FILE>"), N_("get destination path of FILE (See Plugins Configuration)") },
+	{ NULL, "--get-file-info",      gr_file_info,           FALSE, FALSE, NULL, N_("get file info") },
+	{ NULL, "--get-filelist:",      gr_filelist,            TRUE,  FALSE, N_("[<FOLDER>]"), N_("get list of files and class") },
+	{ NULL, "--get-filelist-recurse:", gr_filelist_recurse, TRUE,  FALSE, N_("[<FOLDER>]"), N_("get list of files and class recursive") },
+	{ NULL, "--get-rectangle",      gr_rectangle,           FALSE, FALSE, NULL, N_("get rectangle co-ordinates") },
+	{ NULL, "--get-render-intent",  gr_render_intent,       FALSE, FALSE, NULL, N_("get render intent") },
+	{ NULL, "--get-sidecars:",      gr_get_sidecars,        TRUE,  FALSE, N_("<FILE>"), N_("get list of sidecars of FILE") },
+	{ NULL, "--id:",                gr_lw_id,               TRUE, FALSE, N_("<ID>"), N_("window id for following commands") },
+	{ NULL, "--last",               gr_image_last,          FALSE, FALSE, NULL, N_("last image") },
+	{ NULL, "--list-add:",          gr_list_add,            TRUE,  FALSE, N_("<FILE>"), N_("add FILE to command line collection list") },
+	{ NULL, "--list-clear",         gr_list_clear,          FALSE, FALSE, NULL, N_("clear command line collection list") },
 #ifdef HAVE_LUA
 	{ NULL, "--lua:",               gr_lua,                 TRUE, FALSE, N_("<FILE>,<lua script>"), N_("run lua script on FILE") },
 #endif
-	{ NULL, "--PWD:",               gr_pwd,                 TRUE, FALSE, N_("<PWD>"), N_("use PWD as working directory for following commands") },
+	{ NULL, "--new-window",         gr_new_window,          FALSE, FALSE, NULL, N_("new window") },
+	{ "-n", "--next",               gr_image_next,          FALSE, FALSE, NULL, N_("next image") },
+	{ NULL, "--pixel-info",         gr_pixel_info,          FALSE, FALSE, NULL, N_("print pixel info of mouse pointer on current image") },
 	{ NULL, "--print0",             gr_print0,              TRUE, FALSE, NULL, N_("terminate returned data with null character instead of newline") },
+	{ NULL, "--PWD:",               gr_pwd,                 TRUE, FALSE, N_("<PWD>"), N_("use PWD as working directory for following commands") },
+	{ "-q", "--quit",               gr_quit,                FALSE, FALSE, NULL, N_("quit") },
+	{ NULL, "--raise",              gr_raise,               FALSE, FALSE, NULL, N_("bring the Geeqie window to the top") },
+	{ NULL, "raise",                gr_raise,               FALSE, FALSE, NULL, N_("bring the Geeqie window to the top") },
+	{ "-s", "--slideshow",          gr_slideshow_toggle,    FALSE, TRUE,  NULL, N_("toggle slide show") },
+	{ NULL, "--slideshow-recurse:", gr_slideshow_start_rec, TRUE,  FALSE, N_("<FOLDER>"), N_("start recursive slide show in FOLDER") },
+	{ "-ss","--slideshow-start",    gr_slideshow_start,     FALSE, FALSE, NULL, N_("start slide show") },
+	{ "-sS","--slideshow-stop",     gr_slideshow_stop,      FALSE, FALSE, NULL, N_("stop slide show") },
+	{ NULL, "--tell",               gr_file_tell,           FALSE, FALSE, NULL, N_("print filename [and Collection] of current image") },
+	{ "+t", "--tools-show",         gr_tools_show,          FALSE, TRUE,  NULL, N_("show tools") },
+	{ "-t", "--tools-hide",	        gr_tools_hide,          FALSE, TRUE,  NULL, N_("hide tools") },
+	{ NULL, "--view:",              gr_file_view,           TRUE,  FALSE, N_("<FILE>"), N_("open FILE in new window") },
+	{ NULL, "view:",                gr_file_view,           TRUE,  FALSE, N_("<FILE>"), N_("open FILE in new window") },
 	{ NULL, NULL, NULL, FALSE, FALSE, NULL, NULL }
 };
 
@@ -1452,19 +1520,18 @@ void remote_help(void)
 		{
 		if (remote_commands[i].description)
 			{
-			s_opt_param = g_strconcat(remote_commands[i].opt_s, remote_commands[i].parameter, NULL);
+			s_opt_param = g_strdup(remote_commands[i].opt_s  ? remote_commands[i].opt_s : "" );
 			l_opt_param = g_strconcat(remote_commands[i].opt_l, remote_commands[i].parameter, NULL);
-			printf_term(FALSE, "  %-11s%-1s %-30s%-s\n",
-				    (remote_commands[i].opt_s) ? s_opt_param : "",
-				    (remote_commands[i].opt_s && remote_commands[i].opt_l) ? "," : " ",
-				    (remote_commands[i].opt_l) ? l_opt_param : "",
-				    _(remote_commands[i].description));
+			printf_term(FALSE, "  %-4s %-40s%-s\n",
+					s_opt_param,
+					l_opt_param,
+					remote_commands[i].description);
 			g_free(s_opt_param);
 			g_free(l_opt_param);
 			}
 		i++;
 		}
-	printf_term(FALSE, N_("\n  All other command line parameters are used as plain files if they exists.\n"));
+	printf_term(FALSE, N_("\n\n  All other command line parameters are used as plain files if they exist.\n\n  The name of a collection, with or without either path or extension (.gqv) may be used.\n"));
 }
 
 GList *remote_build_list(GList *list, gint argc, gchar *argv[], GList **errors)
@@ -1492,11 +1559,11 @@ GList *remote_build_list(GList *list, gint argc, gchar *argv[], GList **errors)
 }
 
 /**
- * \param arg_exec Binary (argv0)
- * \param remote_list Evaluated and recognized remote commands
- * \param path The current path
- * \param cmd_list List of all non collections in Path
- * \param collection_list List of all collections in argv
+ * @param arg_exec Binary (argv0)
+ * @param remote_list Evaluated and recognized remote commands
+ * @param path The current path
+ * @param cmd_list List of all non collections in Path (gchar *path)
+ * @param collection_list List of all collections in argv
  */
 void remote_control(const gchar *arg_exec, GList *remote_list, const gchar *path,
 		    GList *cmd_list, GList *collection_list)
@@ -1608,15 +1675,12 @@ void remote_control(const gchar *arg_exec, GList *remote_list, const gchar *path
 		work = cmd_list;
 		while (work)
 			{
-			FileData *fd;
 			gchar *text;
 
-			fd = work->data;
-			work = work->next;
-
-			text = g_strconcat(prefix, fd->path, NULL);
+			text = g_strconcat(prefix, work->data, NULL);
 			remote_client_send(rc, text);
 			g_free(text);
+			work = work->next;
 
 			sent = TRUE;
 			}
