@@ -145,12 +145,24 @@ static void thumb_loader_done_cb(ImageLoader *il, gpointer data)
 		return;
 		}
 
+	if(!tl->cache_hit)
+		{
+			// apply color correction, if required
+			thumb_loader_std_calibrate_pixbuf(tl->fd, pixbuf);
+		}
 
 	if (!tl->cache_hit && options->image.exif_rotate_enable)
 		{
 		if (!tl->fd->exif_orientation)
 			{
-			tl->fd->exif_orientation = metadata_read_int(tl->fd, ORIENTATION_KEY, EXIF_ORIENTATION_TOP_LEFT);
+			if (g_strcmp0(il->fd->format_name, "heif") != 0)
+				{
+				tl->fd->exif_orientation = metadata_read_int(tl->fd, ORIENTATION_KEY, EXIF_ORIENTATION_TOP_LEFT);
+				}
+			else
+				{
+				tl->fd->exif_orientation = EXIF_ORIENTATION_TOP_LEFT;
+				}
 			}
 
 		if (tl->fd->exif_orientation != EXIF_ORIENTATION_TOP_LEFT)
@@ -510,7 +522,7 @@ void thumb_notify_cb(FileData *fd, NotifyType type, gpointer data)
  *
  * Note: Code has been modified to fit the style of the other code, and to use
  *       a few more glib-isms.
- * 08-28-2000: Updated to return a gdk_pixbuf, Imlib is dieing a death here.
+ * 08-28-2000: Updated to return a gdk_pixbuf, Imlib is dying a death here.
  */
 
 #define XV_BUFFER 2048
