@@ -178,7 +178,7 @@ gchar *path_from_utf8(const gchar *utf8)
 		}
 	if (!path)
 		{
-		/* if invalid UTF-8, text probaby still in original form, so just copy it */
+		/* if invalid UTF-8, text probably still in original form, so just copy it */
 		path = g_strdup(utf8);
 		}
 
@@ -860,7 +860,7 @@ gboolean file_extension_match(const gchar *path, const gchar *ext)
 	p = strlen(path);
 	e = strlen(ext);
 
-	/* FIXME: utf8 */
+	/** @FIXME utf8 */
 	return (p > e && g_ascii_strncasecmp(path + p - e, ext, e) == 0);
 }
 
@@ -887,7 +887,7 @@ void parse_out_relatives(gchar *path)
 		{
 		if (path[s] == G_DIR_SEPARATOR && path[s+1] == '.')
 			{
-			/* /. occurence, let's see more */
+			/* /. occurrence, let's see more */
 			gint p = s + 2;
 
 			if (path[p] == G_DIR_SEPARATOR || path[p] == '\0')
@@ -1141,4 +1141,26 @@ gboolean download_web_file(const gchar *text, gboolean minimized, gpointer data)
 	return ret;
 
 }
+
+gboolean rmdir_recursive(GFile *file, GCancellable *cancellable, GError **error)
+{
+	g_autoptr(GFileEnumerator) enumerator = NULL;
+
+	enumerator = g_file_enumerate_children(file, G_FILE_ATTRIBUTE_STANDARD_NAME, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, cancellable, NULL);
+
+	while (enumerator != NULL)
+		{
+		 GFile *child;
+
+		if (!g_file_enumerator_iterate(enumerator, NULL, &child, cancellable, error))
+			return FALSE;
+		if (child == NULL)
+			break;
+		if (!rmdir_recursive(child, cancellable, error))
+			return FALSE;
+		}
+
+	return g_file_delete(file, cancellable, error);
+}
+
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
