@@ -160,7 +160,7 @@ static gboolean tree_edit_by_path_idle_cb(gpointer data)
 		w = MAX(w - sx, sw);
 		}
 
-	gdk_window_get_origin(gtk_tree_view_get_bin_window(ted->tree), &wx, &wy);
+	gdk_window_get_origin(gtk_widget_get_window(gtk_widget_get_parent(GTK_WIDGET(ted->tree))), &wx, &wy);
 
 	x += wx - 2; /* the -val is to 'fix' alignment of entry position */
 	y += wy - 2;
@@ -174,7 +174,7 @@ static gboolean tree_edit_by_path_idle_cb(gpointer data)
 
 	/* grab it */
 	gtk_widget_grab_focus(ted->entry);
-	/* explicitely set the focus flag for the entry, for some reason on popup windows this
+	/* explicitly set the focus flag for the entry, for some reason on popup windows this
 	 * is not set, and causes no edit cursor to appear ( popups not allowed focus? )
 	 */
 	gtk_widget_grab_focus(ted->entry);
@@ -231,7 +231,7 @@ gboolean tree_edit_by_path(GtkTreeView *tree, GtkTreePath *tpath, gint column, c
 	ted->column = tcolumn;
 	ted->cell = cell;
 
-	gtk_tree_view_scroll_to_cell(ted->tree, ted->path, ted->column, FALSE, 0.0, 0.0);
+	gtk_tree_view_scroll_to_cell(ted->tree, ted->path, ted->column, TRUE, 0.5, 0.0);
 
 	/* create the window */
 
@@ -575,6 +575,10 @@ static gboolean widget_auto_scroll_cb(gpointer data)
 	gint x, y;
 	gint w, h;
 	gint amt = 0;
+#if GTK_CHECK_VERSION(3,0,0)
+	GdkDeviceManager *device_manager;
+	GdkDevice *device;
+#endif
 
 	if (sd->max_step < sd->region_size)
 		{
@@ -582,7 +586,13 @@ static gboolean widget_auto_scroll_cb(gpointer data)
 		}
 
 	window = gtk_widget_get_window(sd->widget);
+#if GTK_CHECK_VERSION(3,0,0)
+	device_manager = gdk_display_get_device_manager(gdk_window_get_display(window));
+	device = gdk_device_manager_get_client_pointer(device_manager);
+	gdk_window_get_device_position(window, device, &x, &y, NULL);
+#else
 	gdk_window_get_pointer(window, &x, &y, NULL);
+#endif
 	w = gdk_window_get_width(window);
 	h = gdk_window_get_height(window);
 
