@@ -98,7 +98,12 @@ static void generic_dialog_add_image(GenericDialog *gd, GtkWidget *box,
 
 		head = pref_label_new(vbox, header1);
 		pref_label_bold(head, TRUE, FALSE);
+#if GTK_CHECK_VERSION(3,16,0)
+		gtk_label_set_xalign(GTK_LABEL(head), 0.0);
+		gtk_label_set_yalign(GTK_LABEL(head), 0.5);
+#else
 		gtk_misc_set_alignment(GTK_MISC(head), 0.0, 0.5);
+#endif
 		}
 
 	imd = image_new(FALSE);
@@ -130,7 +135,12 @@ static void generic_dialog_add_image(GenericDialog *gd, GtkWidget *box,
 
 			head = pref_label_new(vbox, header2);
 			pref_label_bold(head, TRUE, FALSE);
+#if GTK_CHECK_VERSION(3,16,0)
+			gtk_label_set_xalign(GTK_LABEL(head), 0.0);
+			gtk_label_set_yalign(GTK_LABEL(head), 0.5);
+#else
 			gtk_misc_set_alignment(GTK_MISC(head), 0.0, 0.5);
+#endif
 			}
 
 		imd = image_new(FALSE);
@@ -1491,7 +1501,12 @@ static void box_append_safe_delete_status(GenericDialog *gd)
 	label = pref_label_new(gd->vbox, buf);
 	g_free(buf);
 
+#if GTK_CHECK_VERSION(3,16,0)
+	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
+	gtk_label_set_yalign(GTK_LABEL(label), 0.5);
+#else
 	gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+#endif
 	gtk_widget_set_sensitive(label, FALSE);
 }
 
@@ -1512,7 +1527,7 @@ static void file_util_dialog_init_simple_list(UtilityData *ud)
 
 	const gchar *stock_id;
 
-	/* FIXME: use ud->stock_id */
+	/** @FIXME use ud->stock_id */
 	if (ud->type == UTILITY_TYPE_DELETE ||
 	    ud->type == UTILITY_TYPE_DELETE_LINK ||
 	    ud->type == UTILITY_TYPE_DELETE_FOLDER)
@@ -1592,7 +1607,12 @@ static void file_util_dialog_init_dest_folder(UtilityData *ud)
 	generic_dialog_add_message(GENERIC_DIALOG(fdlg), NULL, ud->messages.question, NULL, FALSE);
 
 	label = pref_label_new(GENERIC_DIALOG(fdlg)->vbox, _("Choose the destination folder."));
+#if GTK_CHECK_VERSION(3,16,0)
+	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
+	gtk_label_set_yalign(GTK_LABEL(label), 0.5);
+#else
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+#endif
 	pref_spacer(GENERIC_DIALOG(fdlg)->vbox, 0);
 
 	if (options->with_rename)
@@ -1866,7 +1886,7 @@ void file_util_dialog_run(UtilityData *ud)
 					ud->phase = UTILITY_PHASE_ENTERING;
 					break;
 				case UTILITY_TYPE_RENAME_FOLDER:
-					ud->phase = UTILITY_PHASE_CANCEL; /* FIXME - not handled for now */
+					ud->phase = UTILITY_PHASE_CANCEL; /**< @FIXME not handled for now */
 					file_util_dialog_run(ud);
 					return;
 				}
@@ -2105,7 +2125,12 @@ static void file_util_write_metadata_details_dialog(UtilityData *ud, FileData *f
 
 
 		label = gtk_label_new(title_f);
+#if GTK_CHECK_VERSION(3,16,0)
+		gtk_label_set_xalign(GTK_LABEL(label), 1.0);
+		gtk_label_set_yalign(GTK_LABEL(label), 0.0);
+#else
 		gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.0);
+#endif
 		pref_label_bold(label, TRUE, FALSE);
 		gtk_table_attach(GTK_TABLE(table), label,
 				 0, 1, i, i + 1,
@@ -2115,7 +2140,12 @@ static void file_util_write_metadata_details_dialog(UtilityData *ud, FileData *f
 
 		label = gtk_label_new(value);
 
+#if GTK_CHECK_VERSION(3,16,0)
+		gtk_label_set_xalign(GTK_LABEL(label), 0.0);
+		gtk_label_set_yalign(GTK_LABEL(label), 0.0);
+#else
 		gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
+#endif
 		gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 		gtk_table_attach(GTK_TABLE(table), label,
 				 1, 2, i, i + 1,
@@ -2150,8 +2180,7 @@ static void file_util_mark_ungrouped_files(GList *work)
 		}
 }
 
-
-static void file_util_delete_full(FileData *source_fd, GList *flist, GtkWidget *parent, UtilityPhase phase)
+static void file_util_delete_full(FileData *source_fd, GList *flist, GtkWidget *parent, UtilityPhase phase, FileUtilDoneFunc done_func, gpointer done_data)
 {
 	UtilityData *ud;
 	GList *ungrouped = NULL;
@@ -2186,6 +2215,8 @@ static void file_util_delete_full(FileData *source_fd, GList *flist, GtkWidget *
 	ud->flist = flist;
 	ud->content_list = NULL;
 	ud->parent = parent;
+	ud->done_data = done_data;
+	ud->done_func = done_func;
 
 	ud->details_func = file_util_details_dialog;
 	if(options->file_ops.safe_delete_enable)
@@ -3002,7 +3033,12 @@ static gboolean file_util_write_metadata_first(UtilityType type, UtilityPhase ph
 
 void file_util_delete(FileData *source_fd, GList *source_list, GtkWidget *parent)
 {
-	file_util_delete_full(source_fd, source_list, parent, options->file_ops.confirm_delete ? UTILITY_PHASE_START : UTILITY_PHASE_ENTERING);
+	file_util_delete_full(source_fd, source_list, parent, options->file_ops.confirm_delete ? UTILITY_PHASE_START : UTILITY_PHASE_ENTERING, NULL, NULL);
+}
+
+void file_util_delete_notify_done(FileData *source_fd, GList *source_list, GtkWidget *parent, FileUtilDoneFunc done_func, gpointer done_data)
+{
+	file_util_delete_full(source_fd, source_list, parent, options->file_ops.confirm_delete ? UTILITY_PHASE_START : UTILITY_PHASE_ENTERING, done_func, done_data);
 }
 
 void file_util_write_metadata(FileData *source_fd, GList *source_list, GtkWidget *parent, gboolean force_dialog, FileUtilDoneFunc done_func, gpointer done_data)
@@ -3084,43 +3120,28 @@ void file_util_rename_dir(FileData *source_fd, const gchar *new_path, GtkWidget
 
 void file_util_copy_path_to_clipboard(FileData *fd, gboolean quoted)
 {
-	GtkClipboard *clipboard;
-
 	if (!fd || !*fd->path) return;
 
-	if (options->clipboard_selection == PRIMARY)
+	if (options->clipboard_selection == CLIPBOARD_PRIMARY)
 		{
-		clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_PRIMARY), quoted ? g_shell_quote(fd->path) :  fd->path , -1);
+		}
+	else if (options->clipboard_selection == CLIPBOARD_CLIPBOARD)
+		{
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD), quoted ? g_shell_quote(fd->path) :  fd->path , -1);
 		}
 	else
 		{
-		clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
-		}
-	if (quoted)
-		{
-		gtk_clipboard_set_text(clipboard, g_shell_quote(fd->path), -1);
-		}
-	else
-		{
-		gtk_clipboard_set_text(clipboard, fd->path, -1);
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_PRIMARY), quoted ? g_shell_quote(fd->path) :  fd->path , -1);
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD), quoted ? g_shell_quote(fd->path) :  fd->path , -1);
 		}
 }
 
 void file_util_copy_path_list_to_clipboard(GList *list, gboolean quoted)
 {
-	GtkClipboard *clipboard;
 	GList *work;
 	GString *new;
 
-	if (options->clipboard_selection == PRIMARY)
-		{
-		clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
-		}
-	else
-		{
-		clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
-		}
-
 	new = g_string_new("");
 	work = list;
 	while (work) {
@@ -3140,7 +3161,20 @@ void file_util_copy_path_list_to_clipboard(GList *list, gboolean quoted)
 		if (work) g_string_append_c(new, ' ');
 		}
 
-	gtk_clipboard_set_text(clipboard, new->str, new->len);
+	if (options->clipboard_selection == CLIPBOARD_PRIMARY)
+		{
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_PRIMARY), new->str, new->len);
+		}
+	else if  (options->clipboard_selection == CLIPBOARD_CLIPBOARD)
+		{
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD), new->str, new->len);
+		}
+	else
+		{
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_PRIMARY), new->str, new->len);
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD), new->str, new->len);
+		}
+
 	g_string_free(new, TRUE);
 	filelist_free(list);
 }
