@@ -51,8 +51,7 @@ static PixmapFolders *folder_icons_new(GtkWidget *widget)
 	pf->open   = gtk_widget_render_icon(widget, GTK_STOCK_OPEN, size, NULL);
 	pf->deny   = gtk_widget_render_icon(widget, GTK_STOCK_STOP, size, NULL);
 	pf->parent = gtk_widget_render_icon(widget, GTK_STOCK_GO_UP, size, NULL);
-	/* FIXME: this is not a suitable icon */
-	pf->link = gtk_widget_render_icon(widget, GTK_STOCK_REDO, size, NULL);
+	pf->link = gtk_widget_render_icon(widget, GTK_STOCK_REDO, size, NULL); /** @FIXME this is not a suitable icon */
 #else
 	/* GQView legacy icons */
 	pf->close  = pixbuf_inline(PIXBUF_INLINE_FOLDER_CLOSED);
@@ -880,7 +879,7 @@ static void vd_dnd_drop_receive(GtkWidget *widget,
 
 		if (active)
 			{
-/* FIXME: With GTK2 gdk_drag_context_get_actions() shows the state of the
+/** @FIXME With GTK2 gdk_drag_context_get_actions() shows the state of the
  * shift and control keys during the drag operation. With GTK3 this is not
  * so. This is a workaround.
  */
@@ -1187,9 +1186,36 @@ gboolean vd_press_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
 {
 	ViewDir *vd = data;
 	gboolean ret = FALSE;
+	FileData *fd;
+	GtkTreePath *tpath;
+	GtkTreeIter iter;
+	NodeData *nd = NULL;
+	GtkTreeModel *store;
 
 	if (bevent->button == MOUSE_BUTTON_RIGHT)
 		{
+		if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(widget), bevent->x, bevent->y, &tpath, NULL, NULL, NULL))
+			{
+			store = gtk_tree_view_get_model(GTK_TREE_VIEW(widget));
+			gtk_tree_model_get_iter(store, &iter, tpath);
+
+			switch (vd->type)
+				{
+				case DIRVIEW_LIST:
+					gtk_tree_model_get(store, &iter, DIR_COLUMN_POINTER, &fd, -1);
+					vd->click_fd = fd;
+					break;
+				case DIRVIEW_TREE:
+					gtk_tree_model_get(store, &iter, DIR_COLUMN_POINTER, &nd, -1);
+					vd->click_fd = (nd) ? nd->fd : NULL;
+				}
+
+			if (vd->click_fd)
+				{
+				vd_color_set(vd, vd->click_fd, TRUE);
+				}
+			}
+
 		vd->popup = vd_pop_menu(vd, vd->click_fd);
 		gtk_menu_popup(GTK_MENU(vd->popup), NULL, NULL, NULL, NULL,
 			       bevent->button, bevent->time);
