@@ -28,6 +28,7 @@
 #include "history_list.h"
 #include "layout.h"
 #include "menu.h"
+#include "misc.h"
 #include "pixbuf_util.h"
 #include "thumb.h"
 #include "ui_menu.h"
@@ -77,11 +78,16 @@ FileData *vf_index_get_data(ViewFile *vf, gint row)
 
 gint vf_index_by_fd(ViewFile *vf, FileData *fd)
 {
+	gint ret;
+
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_index_by_fd(vf, fd);
-	case FILEVIEW_ICON: return vficon_index_by_fd(vf, fd);
+	case FILEVIEW_LIST: ret = vflist_index_by_fd(vf, fd); break;
+	case FILEVIEW_ICON: ret = vficon_index_by_fd(vf, fd); break;
+	default: ret = 0;
 	}
+
+	return ret;
 }
 
 guint vf_count(ViewFile *vf, gint64 *bytes)
@@ -128,12 +134,16 @@ GList *vf_get_list(ViewFile *vf)
 static gboolean vf_press_key_cb(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
 	ViewFile *vf = data;
+	gboolean ret;
 
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_press_key_cb(widget, event, data);
-	case FILEVIEW_ICON: return vficon_press_key_cb(widget, event, data);
+	case FILEVIEW_LIST: ret = vflist_press_key_cb(widget, event, data); break;
+	case FILEVIEW_ICON: ret = vficon_press_key_cb(widget, event, data); break;
+	default: ret = FALSE;
 	}
+
+	return ret;
 }
 
 /*
@@ -145,23 +155,31 @@ static gboolean vf_press_key_cb(GtkWidget *widget, GdkEventKey *event, gpointer
 static gboolean vf_press_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
 {
 	ViewFile *vf = data;
+	gboolean ret;
 
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_press_cb(widget, bevent, data);
-	case FILEVIEW_ICON: return vficon_press_cb(widget, bevent, data);
+	case FILEVIEW_LIST: ret = vflist_press_cb(widget, bevent, data); break;
+	case FILEVIEW_ICON: ret = vficon_press_cb(widget, bevent, data); break;
+	default: ret = FALSE;
 	}
+
+	return ret;
 }
 
 static gboolean vf_release_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
 {
 	ViewFile *vf = data;
+	gboolean ret;
 
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_release_cb(widget, bevent, data);
-	case FILEVIEW_ICON: return vficon_release_cb(widget, bevent, data);
+	case FILEVIEW_LIST: ret = vflist_release_cb(widget, bevent, data); break;
+	case FILEVIEW_ICON: ret = vficon_release_cb(widget, bevent, data); break;
+	default: ret = FALSE;
 	}
+
+	return ret;
 }
 
 
@@ -173,29 +191,44 @@ static gboolean vf_release_cb(GtkWidget *widget, GdkEventButton *bevent, gpointe
 
 guint vf_selection_count(ViewFile *vf, gint64 *bytes)
 {
+	guint ret;
+
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_selection_count(vf, bytes);
-	case FILEVIEW_ICON: return vficon_selection_count(vf, bytes);
+	case FILEVIEW_LIST: ret = vflist_selection_count(vf, bytes); break;
+	case FILEVIEW_ICON: ret = vficon_selection_count(vf, bytes); break;
+	default: ret = 0;
 	}
+
+	return ret;
 }
 
 GList *vf_selection_get_list(ViewFile *vf)
 {
+	GList *ret;
+
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_selection_get_list(vf);
-	case FILEVIEW_ICON: return vficon_selection_get_list(vf);
+	case FILEVIEW_LIST: ret = vflist_selection_get_list(vf); break;
+	case FILEVIEW_ICON: ret = vficon_selection_get_list(vf); break;
+	default: ret = NULL;
 	}
+
+	return ret;
 }
 
 GList *vf_selection_get_list_by_index(ViewFile *vf)
 {
+	GList *ret;
+
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_selection_get_list_by_index(vf);
-	case FILEVIEW_ICON: return vficon_selection_get_list_by_index(vf);
+	case FILEVIEW_LIST: ret = vflist_selection_get_list_by_index(vf); break;
+	case FILEVIEW_ICON: ret = vficon_selection_get_list_by_index(vf); break;
+	default: ret = NULL;
 	}
+
+	return ret;
 }
 
 void vf_select_all(ViewFile *vf)
@@ -234,6 +267,15 @@ void vf_select_by_fd(ViewFile *vf, FileData *fd)
 	}
 }
 
+void vf_select_list(ViewFile *vf, GList *list)
+{
+	switch (vf->type)
+	{
+	case FILEVIEW_LIST: vflist_select_list(vf, list); break;
+	case FILEVIEW_ICON: vficon_select_list(vf, list); break;
+	}
+}
+
 void vf_mark_to_selection(ViewFile *vf, gint mark, MarkToSelectionMode mode)
 {
 	switch (vf->type)
@@ -276,20 +318,30 @@ static void vf_dnd_init(ViewFile *vf)
 
 GList *vf_pop_menu_file_list(ViewFile *vf)
 {
+	GList *ret;
+
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_pop_menu_file_list(vf);
-	case FILEVIEW_ICON: return vficon_pop_menu_file_list(vf);
+	case FILEVIEW_LIST: ret = vflist_pop_menu_file_list(vf); break;
+	case FILEVIEW_ICON: ret = vficon_pop_menu_file_list(vf); break;
+	default: ret = NULL;
 	}
+
+	return ret;
 }
 
 GList *vf_selection_get_one(ViewFile *vf, FileData *fd)
 {
+	GList *ret;
+
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_selection_get_one(vf, fd);
-	case FILEVIEW_ICON: return vficon_selection_get_one(vf, fd);
+	case FILEVIEW_LIST: ret = vflist_selection_get_one(vf, fd); break;
+	case FILEVIEW_ICON: ret = vficon_selection_get_one(vf, fd); break;
+	default: ret = NULL;
 	}
+
+	return ret;
 }
 
 static void vf_pop_menu_edit_cb(GtkWidget *widget, gpointer data)
@@ -315,6 +367,36 @@ static void vf_pop_menu_view_cb(GtkWidget *widget, gpointer data)
 	}
 }
 
+static void vf_pop_menu_open_archive_cb(GtkWidget *widget, gpointer data)
+{
+	ViewFile *vf = data;
+	LayoutWindow *lw_new;
+	FileData *fd;
+	gchar *dest_dir;
+
+	switch (vf->type)
+	{
+	case FILEVIEW_LIST:
+		fd = (VFLIST(vf)->click_fd);
+		break;
+	case FILEVIEW_ICON:
+		fd = (VFICON(vf)->click_fd);
+		break;
+	}
+
+	dest_dir = open_archive(fd);
+	if (dest_dir)
+		{
+		lw_new = layout_new_from_default();
+		layout_set_path(lw_new, dest_dir);
+		g_free(dest_dir);
+		}
+	else
+		{
+		warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GTK_STOCK_DIALOG_WARNING, NULL);
+		}
+}
+
 static void vf_pop_menu_copy_cb(GtkWidget *widget, gpointer data)
 {
 	ViewFile *vf = data;
@@ -535,20 +617,30 @@ GtkWidget *vf_pop_menu(ViewFile *vf)
 	GtkWidget *item;
 	GtkWidget *submenu;
 	gboolean active = FALSE;
+	gboolean class_archive = FALSE;
+	GtkAccelGroup *accel_group;
 
 	switch (vf->type)
 	{
 	case FILEVIEW_LIST:
 		vflist_color_set(vf, VFLIST(vf)->click_fd, TRUE);
 		active = (VFLIST(vf)->click_fd != NULL);
+		class_archive = (VFLIST(vf)->click_fd != NULL && VFLIST(vf)->click_fd->format_class == FORMAT_CLASS_ARCHIVE);
 		break;
 	case FILEVIEW_ICON:
 		active = (VFICON(vf)->click_fd != NULL);
+		class_archive = (VFICON(vf)->click_fd != NULL && VFICON(vf)->click_fd->format_class == FORMAT_CLASS_ARCHIVE);
 		break;
 	}
 
 	menu = popup_menu_short_lived();
 
+	accel_group = gtk_accel_group_new();
+	gtk_menu_set_accel_group(GTK_MENU(menu), accel_group);
+
+	g_object_set_data(G_OBJECT(menu), "window_keys", NULL);
+	g_object_set_data(G_OBJECT(menu), "accel_group", accel_group);
+
 	g_signal_connect(G_OBJECT(menu), "destroy",
 			 G_CALLBACK(vf_popup_destroy_cb), vf);
 
@@ -606,6 +698,8 @@ GtkWidget *vf_pop_menu(ViewFile *vf)
 	menu_item_add_stock_sensitive(menu, _("View in _new window"), GTK_STOCK_NEW, active,
 				      G_CALLBACK(vf_pop_menu_view_cb), vf);
 
+	menu_item_add_stock_sensitive(menu, _("Open archive"), GTK_STOCK_OPEN, active & class_archive, G_CALLBACK(vf_pop_menu_open_archive_cb), vf);
+
 	menu_item_add_divider(menu);
 	menu_item_add_stock_sensitive(menu, _("_Copy..."), GTK_STOCK_COPY, active,
 				      G_CALLBACK(vf_pop_menu_copy_cb), vf);
@@ -613,9 +707,9 @@ GtkWidget *vf_pop_menu(ViewFile *vf)
 				G_CALLBACK(vf_pop_menu_move_cb), vf);
 	menu_item_add_sensitive(menu, _("_Rename..."), active,
 				G_CALLBACK(vf_pop_menu_rename_cb), vf);
-	menu_item_add_sensitive(menu, _("_Copy path"), active,
+	menu_item_add_sensitive(menu, _("_Copy path to clipboard"), active,
 				G_CALLBACK(vf_pop_menu_copy_path_cb), vf);
-	menu_item_add_sensitive(menu, _("_Copy path unquoted"), active,
+	menu_item_add_sensitive(menu, _("_Copy path unquoted to clipboard"), active,
 				G_CALLBACK(vf_pop_menu_copy_path_unquoted_cb), vf);
 	menu_item_add_divider(menu);
 	menu_item_add_stock_sensitive(menu,
@@ -652,10 +746,10 @@ GtkWidget *vf_pop_menu(ViewFile *vf)
 	item = menu_item_add(menu, _("_Sort"), NULL, NULL);
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
 
-	item = menu_item_add_radio(menu, _("View as _List"), GINT_TO_POINTER(FILEVIEW_LIST), vf->type == FILEVIEW_LIST,
+	item = menu_item_add_radio(menu, _("Images as List"), GINT_TO_POINTER(FILEVIEW_LIST), vf->type == FILEVIEW_LIST,
                                            G_CALLBACK(vf_pop_menu_toggle_view_type_cb), vf);
 
-	item = menu_item_add_radio(menu, _("View as _Icons"), GINT_TO_POINTER(FILEVIEW_ICON), vf->type == FILEVIEW_ICON,
+	item = menu_item_add_radio(menu, _("Images as Icons"), GINT_TO_POINTER(FILEVIEW_ICON), vf->type == FILEVIEW_ICON,
                                            G_CALLBACK(vf_pop_menu_toggle_view_type_cb), vf);
 
 	switch (vf->type)
@@ -689,20 +783,30 @@ GtkWidget *vf_pop_menu(ViewFile *vf)
 
 gboolean vf_refresh(ViewFile *vf)
 {
+	gboolean ret;
+
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_refresh(vf);
-	case FILEVIEW_ICON: return vficon_refresh(vf);
+	case FILEVIEW_LIST: ret = vflist_refresh(vf); break;
+	case FILEVIEW_ICON: ret = vficon_refresh(vf); break;
+	default: ret = FALSE;
 	}
+
+	return ret;
 }
 
 gboolean vf_set_fd(ViewFile *vf, FileData *dir_fd)
 {
+	gboolean ret;
+
 	switch (vf->type)
 	{
-	case FILEVIEW_LIST: return vflist_set_fd(vf, dir_fd);
-	case FILEVIEW_ICON: return vficon_set_fd(vf, dir_fd);
+	case FILEVIEW_LIST: ret = vflist_set_fd(vf, dir_fd); break;
+	case FILEVIEW_ICON: ret = vficon_set_fd(vf, dir_fd); break;
+	default: ret = FALSE;
 	}
+
+	return ret;
 }
 
 static void vf_destroy_cb(GtkWidget *widget, gpointer data)
@@ -1616,7 +1720,7 @@ void vf_notify_cb(FileData *fd, NotifyType type, gpointer data)
 
 	NotifyType interested = NOTIFY_CHANGE | NOTIFY_REREAD | NOTIFY_GROUPING;
 	if (vf->marks_enabled) interested |= NOTIFY_MARKS | NOTIFY_METADATA;
-	/* FIXME: NOTIFY_METADATA should be checked by the keyword-to-mark functions and converted to NOTIFY_MARKS only if there was a change */
+	/** @FIXME NOTIFY_METADATA should be checked by the keyword-to-mark functions and converted to NOTIFY_MARKS only if there was a change */
 
 	if (!(type & interested) || vf->refresh_idle_id || !vf->dir_fd) return;
 
