@@ -246,7 +246,7 @@ void help_window_show(const gchar *key)
 
 	if (key && strstr(key, ".html") != 0)
 		{
-		path = g_build_filename(GQ_HTMLDIR, key, NULL);
+		path = g_build_filename(gq_htmldir, key, NULL);
 		if (!isfile(path))
 			{
 			if (g_strcmp0(key, "index.html") == 0)
@@ -272,18 +272,18 @@ void help_window_show(const gchar *key)
 
 	if (!strcmp(key, "release_notes"))
 		{
-		path = g_build_filename(GQ_HELPDIR, "README.html", NULL);
+		path = g_build_filename(gq_helpdir, "README.html", NULL);
 		if (isfile(path))
 			{
 			g_free(path);
-			path = g_build_filename("file://", GQ_HELPDIR, "README.html", NULL);
+			path = g_build_filename("file://", gq_helpdir, "README.html", NULL);
 			help_browser_run(path);
 			g_free(path);
 			}
 		else
 			{
 			g_free(path);
-			path = g_build_filename(GQ_HELPDIR, "README.md", NULL);
+			path = g_build_filename(gq_helpdir, "README.md", NULL);
 			help_window = help_window_new(_("Help"), "help", path, key);
 			g_free(path);
 
@@ -293,18 +293,18 @@ void help_window_show(const gchar *key)
 		}
 	else
 		{
-		path = g_build_filename(GQ_HELPDIR, "ChangeLog.html", NULL);
+		path = g_build_filename(gq_helpdir, "ChangeLog.html", NULL);
 		if (isfile(path))
 			{
 			g_free(path);
-			path = g_build_filename("file://", GQ_HELPDIR, "ChangeLog.html", NULL);
+			path = g_build_filename("file://", gq_helpdir, "ChangeLog.html", NULL);
 			help_browser_run(path);
 			g_free(path);
 			}
 		else
 			{
 			g_free(path);
-			path = g_build_filename(GQ_HELPDIR, "ChangeLog", NULL);
+			path = g_build_filename(gq_helpdir, "ChangeLog", NULL);
 			help_window = help_window_new(_("Help"), "help", path, key);
 			g_free(path);
 
@@ -377,10 +377,20 @@ void help_search_window_show()
 				  help_search_window_ok_cb, TRUE);
 
 	label1 = pref_label_new(GENERIC_DIALOG(gd)->vbox, _("Search engine:"));
-	gtk_misc_set_alignment(GTK_MISC(label1), 0.0, 0.5);
+#if GTK_CHECK_VERSION(3,16,0)
+	gtk_label_set_xalign(GTK_LABEL(label1), 0.0);
+	gtk_label_set_yalign(GTK_LABEL(label1), 0.5);
+#else
+   gtk_misc_set_alignment(GTK_MISC(label1), 0.0, 0.5);
+#endif
 
 	label2 = pref_label_new(GENERIC_DIALOG(gd)->vbox, options->help_search_engine);
-	gtk_misc_set_alignment(GTK_MISC(label2), 0.0, 0.5);
+#if GTK_CHECK_VERSION(3,16,0)
+	gtk_label_set_xalign(GTK_LABEL(label2), 0.0);
+	gtk_label_set_yalign(GTK_LABEL(label2), 0.5);
+#else
+   gtk_misc_set_alignment(GTK_MISC(label2), 0.0, 0.5);
+#endif
 	pref_spacer(GENERIC_DIALOG(gd)->vbox, 0);
 
 	table = pref_table_new(gd->vbox, 3, 1, FALSE, TRUE);
